#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    :   __init__.py
@Time    :   2022/04/29 15:16:47
@Author  :   Calros Teng 
@Version :   1.0
@Contact :   303359166@qq.com
@License :   (C)Copyright 2017-2018, Xin Yuan Studio
@Desc    :   页面基类
"""

# here put the import lib
from PySide6.QtWidgets import QWidget
from perfcat.ui.constant import ButtonStyle

from perfcat.ui.widgets import notification


class Page(QWidget):
    def __init__(self, parent) -> None:
        super().__init__(parent)
        self._setting_widget = None

    def clear_stylesheet(self):
        self.setStyleSheet("")

    @property
    def setting_widget(self) -> "Page":
        """
        返回设置页widget

        _extended_summary_

        Returns:
            _type_: _description_
        """
        return self._setting_widget

    def notify(self, msg:str="警告", style:ButtonStyle=ButtonStyle.warning):
        notification.Notification(self, msg, style).show()


# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'profiler.ui'
##
## Created by: Qt User Interface Compiler version 6.4.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QDate, QDateTime, QLocale,
    QMetaObject, QObject, QPoint, QRect,
    QSize, QTime, QUrl, Qt)
from PySide6.QtGui import (QBrush, QColor, QConicalGradient, QCursor,
    QFont, QFontDatabase, QGradient, QIcon,
    QImage, QKeySequence, QLinearGradient, QPainter,
    QPalette, QPixmap, QRadialGradient, QTransform)
from PySide6.QtWidgets import (QApplication, QComboBox, QFrame, QGridLayout,
    QHBoxLayout, QHeaderView, QPushButton, QScrollArea,
    QScrollBar, QSizePolicy, QSplitter, QTabWidget,
    QTableWidget, QTableWidgetItem, QToolButton, QVBoxLayout,
    QWidget)
import asset_rc

class Ui_Profiler(object):
    def setupUi(self, Profiler):
        if not Profiler.objectName():
            Profiler.setObjectName(u"Profiler")
        Profiler.resize(1113, 795)
        icon = QIcon()
        icon.addFile(u":/icon_w/assets/svg_white/android.svg", QSize(), QIcon.Normal, QIcon.Off)
        icon.addFile(u":/icon_b/assets/svg_blue/android.svg", QSize(), QIcon.Normal, QIcon.On)
        Profiler.setWindowIcon(icon)
        Profiler.setStyleSheet(u"*{\n"
"    border-radius:8;\n"
"    color:#6c7c96;\n"
"}\n"
"\n"
"#container {\n"
"background-color:#2c313c;\n"
"}\n"
"\n"
"#left_menu_frame{\n"
"background-color:#1b1e23;\n"
"}\n"
"\n"
"#title_bar_frame{\n"
"background-color:#343b48;\n"
"}\n"
"\n"
"#status_bar_frame{\n"
"background-color:#343b48;\n"
"}\n"
"\n"
"#content_frame{\n"
"background-color:#343b48;\n"
"}\n"
"\n"
"#setting_frame {\n"
"background-color:#3c4454;\n"
"}\n"
"\n"
"#left_column_frame {\n"
"background-color:#343b48;\n"
"}\n"
"\n"
"/* \u4fa7\u8fb9\u83dc\u5355\u680f\u6837\u5f0f */\n"
"\n"
"#LeftMenu {\n"
"background-color: #005dfd;\n"
"}\n"
"\n"
"#LeftMenu QPushButton {\n"
"background-color:#1b1e23;\n"
"height:40;\n"
"text-align:left;\n"
"padding-left:15;\n"
"padding-top:2;\n"
"padding-bottom:2;\n"
"color:#6b7884;\n"
"}\n"
"\n"
"#LeftMenu QPushButton:hover{\n"
"background-color:#21252d;\n"
"}\n"
"\n"
"#LeftMenu QPushButton:pressed{\n"
"background-color:#2c313c;\n"
"}\n"
"\n"
"#LeftMenu QPushButton:checked{\n"
"background-color:#2c313c;\n"
"}\n"
""
                        "\n"
"#LeftMenu QPushButton:focus{\n"
"border:none;\n"
"}\n"
"\n"
"\n"
"#LeftMenu #bottom{\n"
"border-top:1 solid #272c36;\n"
"border-radius: 0;\n"
"}\n"
"\n"
"#LeftMenu #nav_menu {\n"
"border-top:1 solid #272c36;\n"
"border-radius: 0\uff1b\n"
"}\n"
"\n"
"#LeftMenu #scrollArea,#scrollAreaWidgetContents_3{\n"
"background-color:#1b1e23;\n"
"border:none;\n"
"}\n"
"\n"
"#LeftMenu #btn_toggle:checked{\n"
"background-color:#21252d;\n"
"}\n"
"\n"
"\n"
"/* \u6807\u9898\u680f\u6837\u5f0f */\n"
"\n"
"#TitleBar #bg{\n"
"background-color:#343b48;\n"
"border-radius:8;\n"
"}\n"
"\n"
"#TitleBar #logo {\n"
"border: 1px solid #3c4454;\n"
"padding-right:10px;\n"
"border-top:none;\n"
"border-bottom:none;\n"
"border-left:none;\n"
"margin-right:5px;\n"
"border-radius:0;\n"
"}\n"
"\n"
"#TitleBar  #logo_title{\n"
"color:#77b3f1;\n"
"font-size:20px;\n"
"font-weight:bold;\n"
"}\n"
"\n"
"#TitleBar  #lb_title{\n"
"font-size:14px;\n"
"color:#6c7c96;\n"
"}\n"
"\n"
"#TitleBar  QToolButton{\n"
"background-color:#343b48;\n"
"border:none;\n"
""
                        "border-radius:4;\n"
"padding: 4;\n"
"}\n"
"\n"
"#TitleBar QToolButton:hover,\n"
"#TitleBar QToolButton:checked{\n"
"background-color:#3c4454;\n"
"}\n"
"\n"
"\n"
"#TitleBar QToolButton:pressed{\n"
"background-color:#e2e9f7;\n"
"}\n"
"\n"
"#TitleBar #tool{\n"
"border:1px solid #3c4454;\n"
"border-top:none;\n"
"border-bottom:none;\n"
"margin-right:5px;\n"
"border-radius:0;\n"
"}\n"
"\n"
"\n"
"#LeftColumn{\n"
"background-color:#343b48;\n"
"}\n"
"\n"
"#LeftColumn #top{\n"
"background-color: #3c4454;\n"
"}\n"
"\n"
"#leftColumn #icon{\n"
"\n"
"}\n"
"\n"
"#LeftColumn #title{\n"
"color:#6c7c96;\n"
"}\n"
"\n"
"#LeftColumn QToolButton{\n"
"border:none;\n"
"padding:4;\n"
"background-color: #3c4454;\n"
"}\n"
"\n"
"#LeftColumn #btn_close:hover{\n"
"background-color:#343b48;\n"
"}\n"
"\n"
"#LeftColumn #btn_close:pressed{\n"
"background-color:#1b1e23;\n"
"}\n"
"\n"
"\n"
"/* \u901a\u7528\u63a7\u4ef6 */\n"
"\n"
"QToolTip { \n"
"color:#6b7884;\n"
"background-color: #1b1e23; \n"
"border-left: 2px solid #4f9fee;\n"
"border-radius:"
                        " 8px;\n"
"}\n"
"\n"
"QGroupBox{\n"
"	border: 2px solid gray; \n"
"    border-radius: 3px; \n"
"    margin:10;\n"
"}\n"
"\n"
"QGroupBox::title { \n"
"    subcontrol-position: center top; /* position at the top left*/ \n"
"	subcontrol-origin: border;\n"
"	margin-top:-20px;\n"
"\n"
"}\n"
"\n"
"/* Button */\n"
"QAbstractButton{\n"
"background-color:#1b1e23;\n"
"border:none;\n"
"border-radius:4;\n"
"padding: 4;\n"
"outline:none;\n"
"width:36;\n"
"height:36;\n"
"}\n"
"\n"
"QAbstractButton:hover,\n"
"QAbstractButton:checked{\n"
"background-color:#21252d;\n"
"}\n"
"\n"
"\n"
"QAbstractButton:pressed{\n"
"background-color:#272c36;\n"
"}\n"
"\n"
"QAbstractButton:disabled{\n"
"background-color: #272c36;\n"
"}\n"
"\n"
"QAbstractButton:checked{\n"
"background-color:#568af2;\n"
"color:black;\n"
"}\n"
"\n"
"QAbstractButton:focus{\n"
"border: 2px solid #568af2;\n"
"}\n"
"\n"
"QAbstractButton[style~='success']:checked{\n"
"    background-color: #67c23a;\n"
"}\n"
"QAbstractButton[style~='warning']:checked{\n"
"    background-col"
                        "or: #e6a23c;\n"
"}\n"
"QAbstractButton[style~='danger']:checked{\n"
"    background-color: #f56c6c;\n"
"}\n"
"QAbstractButton[style~='info']:checked{\n"
"    background-color: #909399;\n"
"}\n"
"\n"
"\n"
"/* CheckBox */\n"
"\n"
"QCheckBox::indicator{\n"
"    border:2px solid #6c7c96;\n"
"    border-radius: 2px;\n"
"    width:10px;\n"
"    height:10px;\n"
"    margin-left:8px;\n"
"}\n"
"\n"
"QCheckBox::indicator:checked{\n"
"    border:2px solid black;\n"
"    image: url(:/icon/assets/svg/checkmark.svg);\n"
"}\n"
"\n"
"QRadioButton::indicator{\n"
"    border:1px solid #6c7c96;\n"
"    background-color:#6c7c96;\n"
"    border-radius: 4px;\n"
"    width:10px;\n"
"    height:10px;\n"
"    margin-left:8px;\n"
"}\n"
"\n"
"QRadioButton::indicator:checked{\n"
"    border:1px solid #fff;\n"
"    background-color:black;\n"
"}\n"
"\n"
"/* TextEdit */\n"
"QPlainTextEdit,\n"
"QTextEdit,\n"
"QLineEdit{\n"
"    background-color: #1b1e23;\n"
"    padding:8px;\n"
"}\n"
"\n"
"QPlainTextEdit:focus,\n"
"QTextEdit:focus,\n"
"QLine"
                        "Edit:focus{\n"
"    border: 2px solid #568af2;\n"
"}\n"
"\n"
"QPlainTextEdit:read-only,\n"
"QTextEdit:read-only,\n"
"QLineEdit:read-only{\n"
"    border:none;\n"
"}\n"
"\n"
"/* ProgressBar */\n"
"QProgressBar{\n"
"    background-color: #1b1e23;\n"
"    text-align:center;\n"
"    font-weight: bold;\n"
"}\n"
"\n"
"QProgressBar::chunk:horizontal{\n"
"    background-color: #4f9fee;\n"
"    border-radius: 8px;\n"
"    border-top-right-radius: 0;\n"
"    border-bottom-right-radius:0;\n"
"}\n"
"QProgressBar::chunk:vertical{\n"
"    background-color: #4f9fee;\n"
"    border-radius: 8px;\n"
"    border-top-left-radius: 0;\n"
"    border-top-right-radius:0;\n"
"}\n"
"\n"
"\n"
"/* ScrollBar */\n"
"QScrollBar:horizontal{\n"
"    background-color: #2c313c;\n"
"    border-radius: 0;\n"
"    border:none;\n"
"    max-height: 8px;\n"
"}\n"
"\n"
"QScrollBar::handle:horizontal{\n"
"    background-color:#568af2;\n"
"    border-radius:4px;\n"
"    min-width: 25px;\n"
"}\n"
"\n"
"QScrollBar::add-page:horizontal{\n"
"    background-"
                        "color:none;\n"
"}\n"
"QScrollBar::sub-page:horizontal{\n"
"    background-color:none;\n"
"}\n"
"\n"
"QScrollBar::add-line:horizontal{\n"
"    background-color:#272c36;\n"
"    border:none;\n"
"    width:0px;\n"
"    border-top-right-radius: 4px;\n"
"    border-bottom-right-radius: 4px;\n"
"    subcontrol-posistion:right;\n"
"    subcontrol-origin:margin;\n"
"}\n"
"QScrollBar::sub-line:horizontal{\n"
"    background-color:#272c36;\n"
"    border:none;\n"
"    width:0px;\n"
"    border-top-right-radius: 4px;\n"
"    border-bottom-right-radius: 4px;\n"
"    subcontrol-posistion:right;\n"
"    subcontrol-origin:margin;\n"
"}\n"
"\n"
"/* Vertical */\n"
"QScrollBar:vertical{\n"
"    background-color: #2c313c;\n"
"    border-radius: 0;\n"
"    border:none;\n"
"    max-width: 8px;\n"
"}\n"
"\n"
"QScrollBar::handle:vertical{\n"
"    background-color:#568af2;\n"
"    border-radius:4px;\n"
"    min-height: 25px;\n"
"}\n"
"\n"
"QScrollBar::add-page:vertical{\n"
"    background-color:none;\n"
"}\n"
"QScrollBar::sub-page:ve"
                        "rtical{\n"
"    background-color:none;\n"
"}\n"
"\n"
"QScrollBar::add-line:vertical{\n"
"    background-color:#272c36;\n"
"    border:none;\n"
"    width:0px;\n"
"    border-top-right-radius: 4px;\n"
"    border-top-left-radius: 4px;\n"
"    subcontrol-posistion:right;\n"
"    subcontrol-origin:margin;\n"
"}\n"
"QScrollBar::sub-line:vertical{\n"
"    background-color:#272c36;\n"
"    border:none;\n"
"    width:0px;\n"
"    border-top-right-radius: 4px;\n"
"    border-top-left-radius: 4px;\n"
"    subcontrol-posistion:right;\n"
"    subcontrol-origin:margin;\n"
"}\n"
"\n"
"\n"
"/* Slider */\n"
"\n"
"QSlider:horizontal{\n"
"    margin:8;\n"
"}\n"
"\n"
"QSlider::groove:horizontal{\n"
"    background-color: #1b1e23;\n"
"    border-radius: 4px;\n"
"    margin:0px;\n"
"    height: 10px;\n"
"}\n"
"QSlider::groove:horizontal:hover{\n"
"    background-color: #21252d;\n"
"}\n"
"\n"
"QSlider::handle:horizontal{\n"
"    border:none;\n"
"    height:16px;\n"
"    width:16px;\n"
"    margin: -3px;\n"
"    border-radius: 8px;"
                        "\n"
"    background-color: #4f9fee;\n"
"}\n"
"\n"
"QSlider:vertical{\n"
"    margin:8;\n"
"}\n"
"\n"
"QSlider::groove:vertical{\n"
"    background-color: #1b1e23;\n"
"    border-radius: 4px;\n"
"    margin:0px;\n"
"    width: 10px;\n"
"}\n"
"QSlider::groove:vertical:hover{\n"
"    background-color: #21252d;\n"
"}\n"
"\n"
"QSlider::handle:vertical{\n"
"    border:none;\n"
"    height:16px;\n"
"    width:16px;\n"
"    margin: -3px;\n"
"    border-radius: 8px;\n"
"    background-color: #4f9fee;\n"
"}\n"
"\n"
"\n"
"/* ComboBox */\n"
"\n"
"QComboBox{\n"
"    background-color: #1b1e23;\n"
"    padding:8px;\n"
"    selection-background-color:transparent;\n"
"}\n"
"\n"
"QComboBox::drop-down{\n"
"    border-top-right-radius: 8px;\n"
"    border-bottom-right-radius: 8px;\n"
"    subcontrol-origin:padding;\n"
"    subcontrol-position:center right;\n"
"    background-color:#1b1e23;\n"
"    width:10px;\n"
"    padding:10px;\n"
"}\n"
"\n"
"QComboBox::drop-down:hover{\n"
"    background-color:black;\n"
"}\n"
"\n"
"QComboBox:"
                        ":down-arrow{\n"
"    image:url(:/icon_w/assets/svg_white/circle-down.svg);\n"
"    width: 18px;\n"
"    height:18px;\n"
"}\n"
"\n"
"\n"
"/* TabWidget */\n"
"QTabWidget::pane { /* The tab widget frame */\n"
"    border-top: 2px solid #1b1e23;\n"
"    background-color:#1b1e23;\n"
"    border-radius: 8px;\n"
"    border-top-left-radius:0px;\n"
"}\n"
"\n"
"QTabWidget::tab-bar {\n"
"    left: 0px; /* move to the right by 5px */\n"
"}\n"
"\n"
"/* Style the tab using the tab sub-control. Note that\n"
"    it reads QTabBar _not_ QTabWidget */\n"
"QTabBar::tab {\n"
"    background: #1b1e23;\n"
"    border-bottom-color: #1b1e23; \n"
"    border-top-left-radius: 8px;\n"
"    border-top-right-radius: 8px;\n"
"    min-width: 8ex;\n"
"    padding: 8px;\n"
"}\n"
"\n"
"QTabBar::tab:selected, QTabBar::tab:hover {\n"
"    background: #568af2;\n"
"    color:black;\n"
"}\n"
"\n"
"QTabBar::tab:!selected {\n"
"    margin-top: 2px; /* make non-selected tabs look smaller */\n"
"}\n"
"\n"
"QTableWidget{\n"
"	background-color:#343b48;\n"
""
                        "	padding:5px;\n"
"gridline-color:#2c313c;\n"
"}\n"
"\n"
"QTableWidget::item{\n"
"border-color:none;\n"
"padding-left:5px;\n"
"padding-right:5px;\n"
"gridline-color:rgb(44, 49, 60);\n"
"border-bottom: 1px solid #3c4454;\n"
"}\n"
"\n"
"QTableWidget::item:selected{\n"
"	background-color: #568af2;\n"
"}\n"
"\n"
"QTableWidget QLineEdit{\n"
"	padding:2px;\n"
"background-color:#568af2;\n"
"}\n"
"\n"
"QHeaderView::section{\n"
"	background-color: rgb(33, 37, 43);\n"
"	max-width: 30px;\n"
"	border: 1px solid rgb(44, 49, 58);\n"
"	border-style: none;\n"
"    border-bottom: 1px solid rgb(44, 49, 60);\n"
"    border-right: 1px solid rgb(44, 49, 60);\n"
"}\n"
"\n"
"QTableWidget::horizontalHeader {\n"
"	background-color: rgb(33, 37, 43);\n"
"}\n"
"\n"
"QTableWidget::verticalHeader{\n"
"background-color: rgb(33, 37, 43);\n"
"}\n"
"\n"
"QTableWidget QTableCornerButton::section {\n"
"    border: none;\n"
"	background-color: rgb(33, 37, 43);\n"
"	padding: 3px;\n"
"    border-top-left-radius: 8px;\n"
"}\n"
"\n"
"QHeaderView::sect"
                        "ion:horizontal\n"
"{\n"
"\n"
"	background-color: rgb(33, 37, 43);\n"
"	padding: 3px;\n"
"}\n"
"\n"
"QHeaderView::section:horizontal:first\n"
"{\n"
"\n"
"	background-color: rgb(33, 37, 43);\n"
"	padding: 3px;\n"
"border-top-left-radius: 8px;\n"
"}\n"
"\n"
"QHeaderView::section:horizontal:last\n"
"{\n"
"\n"
"	background-color: rgb(33, 37, 43);\n"
"	padding: 3px;\n"
"border-top-right-radius: 8px;\n"
"}\n"
"\n"
"QHeaderView::section:vertical\n"
"{\n"
"    border: none;\n"
"	background-color: rgb(33, 37, 43);\n"
"	padding-left: 5px;\n"
"    padding-right: 5px;\n"
"    border-bottom: 1px solid #3c4454;\n"
"}\n"
"\n"
"QHeaderView {\n"
"    background-color: #21252b;\n"
"}\n"
"")
        self.verticalLayout = QVBoxLayout(Profiler)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.frame = QFrame(Profiler)
        self.frame.setObjectName(u"frame")
        self.frame.setStyleSheet(u"")
        self.frame.setFrameShape(QFrame.StyledPanel)
        self.frame.setFrameShadow(QFrame.Raised)
        self.horizontalLayout = QHBoxLayout(self.frame)
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.horizontalLayout.setContentsMargins(9, 9, 9, 9)
        self.left = QFrame(self.frame)
        self.left.setObjectName(u"left")
        self.left.setMaximumSize(QSize(240, 16777215))
        self.left.setFrameShape(QFrame.StyledPanel)
        self.left.setFrameShadow(QFrame.Raised)
        self.verticalLayout_2 = QVBoxLayout(self.left)
        self.verticalLayout_2.setSpacing(0)
        self.verticalLayout_2.setObjectName(u"verticalLayout_2")
        self.verticalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.frame_2 = QFrame(self.left)
        self.frame_2.setObjectName(u"frame_2")
        self.frame_2.setFrameShape(QFrame.StyledPanel)
        self.frame_2.setFrameShadow(QFrame.Raised)
        self.verticalLayout_3 = QVBoxLayout(self.frame_2)
        self.verticalLayout_3.setObjectName(u"verticalLayout_3")
        self.verticalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.cbx_device = QComboBox(self.frame_2)
        self.cbx_device.setObjectName(u"cbx_device")
        self.cbx_device.setEnabled(True)
        self.cbx_device.setMinimumSize(QSize(0, 36))

        self.verticalLayout_3.addWidget(self.cbx_device)

        self.cbx_app = QComboBox(self.frame_2)
        self.cbx_app.setObjectName(u"cbx_app")
        self.cbx_app.setEnabled(True)
        self.cbx_app.setMinimumSize(QSize(0, 36))
        self.cbx_app.setEditable(True)

        self.verticalLayout_3.addWidget(self.cbx_app)

        self.horizontalLayout_2 = QHBoxLayout()
        self.horizontalLayout_2.setObjectName(u"horizontalLayout_2")
        self.btn_connect = QPushButton(self.frame_2)
        self.btn_connect.setObjectName(u"btn_connect")
        self.btn_connect.setMaximumSize(QSize(16777215, 36))
        self.btn_connect.setStyleSheet(u"\\")
        icon1 = QIcon()
        icon1.addFile(u":/icon_w/assets/svg_white/power-cord.svg", QSize(), QIcon.Normal, QIcon.Off)
        icon1.addFile(u":/icon/assets/svg/power-cord.svg", QSize(), QIcon.Normal, QIcon.On)
        self.btn_connect.setIcon(icon1)
        self.btn_connect.setCheckable(True)

        self.horizontalLayout_2.addWidget(self.btn_connect)

        self.btn_open = QToolButton(self.frame_2)
        self.btn_open.setObjectName(u"btn_open")
        self.btn_open.setMaximumSize(QSize(36, 36))
        icon2 = QIcon()
        icon2.addFile(u":/icon_w/assets/svg_white/folder-open.svg", QSize(), QIcon.Normal, QIcon.Off)
        icon2.addFile(u":/icon_b/assets/svg_blue/folder-open.svg", QSize(), QIcon.Normal, QIcon.On)
        self.btn_open.setIcon(icon2)

        self.horizontalLayout_2.addWidget(self.btn_open)

        self.btn_save = QToolButton(self.frame_2)
        self.btn_save.setObjectName(u"btn_save")
        self.btn_save.setEnabled(False)
        self.btn_save.setMaximumSize(QSize(36, 36))
        icon3 = QIcon()
        icon3.addFile(u":/icon_w/assets/svg_white/save.svg", QSize(), QIcon.Normal, QIcon.Off)
        icon3.addFile(u":/icon_b/assets/svg_blue/save.svg", QSize(), QIcon.Normal, QIcon.On)
        self.btn_save.setIcon(icon3)

        self.horizontalLayout_2.addWidget(self.btn_save)

        self.btn_record = QToolButton(self.frame_2)
        self.btn_record.setObjectName(u"btn_record")
        self.btn_record.setMaximumSize(QSize(36, 36))
        icon4 = QIcon()
        icon4.addFile(u":/icon_w/assets/svg_white/play2.svg", QSize(), QIcon.Normal, QIcon.Off)
        icon4.addFile(u":/icon/assets/svg/pause.svg", QSize(), QIcon.Normal, QIcon.On)
        self.btn_record.setIcon(icon4)
        self.btn_record.setIconSize(QSize(24, 24))
        self.btn_record.setCheckable(True)

        self.horizontalLayout_2.addWidget(self.btn_record)


        self.verticalLayout_3.addLayout(self.horizontalLayout_2)

        self.tab_main = QTabWidget(self.frame_2)
        self.tab_main.setObjectName(u"tab_main")
        self.tab = QWidget()
        self.tab.setObjectName(u"tab")
        self.verticalLayout_7 = QVBoxLayout(self.tab)
        self.verticalLayout_7.setObjectName(u"verticalLayout_7")
        self.verticalLayout_7.setContentsMargins(2, 2, 2, 2)
        self.tb_device_info = QTableWidget(self.tab)
        if (self.tb_device_info.columnCount() < 2):
            self.tb_device_info.setColumnCount(2)
        __qtablewidgetitem = QTableWidgetItem()
        self.tb_device_info.setHorizontalHeaderItem(0, __qtablewidgetitem)
        __qtablewidgetitem1 = QTableWidgetItem()
        self.tb_device_info.setHorizontalHeaderItem(1, __qtablewidgetitem1)
        self.tb_device_info.setObjectName(u"tb_device_info")
        self.tb_device_info.setEnabled(True)
        self.tb_device_info.setWordWrap(False)
        self.tb_device_info.setCornerButtonEnabled(True)
        self.tb_device_info.setColumnCount(2)
        self.tb_device_info.horizontalHeader().setCascadingSectionResizes(False)
        self.tb_device_info.horizontalHeader().setProperty("showSortIndicator", False)
        self.tb_device_info.horizontalHeader().setStretchLastSection(True)
        self.tb_device_info.verticalHeader().setVisible(False)

        self.verticalLayout_7.addWidget(self.tb_device_info)

        self.btn_copy_info = QPushButton(self.tab)
        self.btn_copy_info.setObjectName(u"btn_copy_info")
        self.btn_copy_info.setEnabled(False)

        self.verticalLayout_7.addWidget(self.btn_copy_info)

        icon5 = QIcon()
        icon5.addFile(u":/icon_w/assets/svg_white/mobile2.svg", QSize(), QIcon.Normal, QIcon.Off)
        icon5.addFile(u":/icon_b/assets/svg_blue/mobile2.svg", QSize(), QIcon.Normal, QIcon.On)
        self.tab_main.addTab(self.tab, icon5, "")

        self.verticalLayout_3.addWidget(self.tab_main)


        self.verticalLayout_2.addWidget(self.frame_2)


        self.horizontalLayout.addWidget(self.left)

        self.right = QFrame(self.frame)
        self.right.setObjectName(u"right")
        self.right.setFrameShape(QFrame.StyledPanel)
        self.right.setFrameShadow(QFrame.Raised)
        self.verticalLayout_4 = QVBoxLayout(self.right)
        self.verticalLayout_4.setObjectName(u"verticalLayout_4")
        self.verticalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.splitter = QSplitter(self.right)
        self.splitter.setObjectName(u"splitter")
        sizePolicy = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.splitter.sizePolicy().hasHeightForWidth())
        self.splitter.setSizePolicy(sizePolicy)
        self.splitter.setOrientation(Qt.Vertical)
        self.splitter.setHandleWidth(1)
        self.frame_4 = QFrame(self.splitter)
        self.frame_4.setObjectName(u"frame_4")
        sizePolicy1 = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Expanding)
        sizePolicy1.setHorizontalStretch(0)
        sizePolicy1.setVerticalStretch(0)
        sizePolicy1.setHeightForWidth(self.frame_4.sizePolicy().hasHeightForWidth())
        self.frame_4.setSizePolicy(sizePolicy1)
        self.frame_4.setStyleSheet(u"")
        self.frame_4.setFrameShape(QFrame.StyledPanel)
        self.frame_4.setFrameShadow(QFrame.Raised)
        self.verticalLayout_5 = QVBoxLayout(self.frame_4)
        self.verticalLayout_5.setObjectName(u"verticalLayout_5")
        self.verticalLayout_5.setContentsMargins(0, 0, 0, 0)
        self.monitor_scollarea = QScrollArea(self.frame_4)
        self.monitor_scollarea.setObjectName(u"monitor_scollarea")
        sizePolicy2 = QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
        sizePolicy2.setHorizontalStretch(0)
        sizePolicy2.setVerticalStretch(100)
        sizePolicy2.setHeightForWidth(self.monitor_scollarea.sizePolicy().hasHeightForWidth())
        self.monitor_scollarea.setSizePolicy(sizePolicy2)
        self.monitor_scollarea.setLayoutDirection(Qt.LeftToRight)
        self.monitor_scollarea.setStyleSheet(u"")
        self.monitor_scollarea.setWidgetResizable(True)
        self.monitor_scollarea.setAlignment(Qt.AlignLeading|Qt.AlignLeft|Qt.AlignTop)
        self.scrollAreaWidgetContents = QWidget()
        self.scrollAreaWidgetContents.setObjectName(u"scrollAreaWidgetContents")
        self.scrollAreaWidgetContents.setGeometry(QRect(0, 0, 849, 445))
        self.scrollAreaWidgetContents.setLayoutDirection(Qt.LeftToRight)
        self.scrollAreaWidgetContents.setStyleSheet(u"#scrollAreaWidgetContents{\n"
"margin-right:5px;\n"
"}")
        self.verticalLayout_6 = QVBoxLayout(self.scrollAreaWidgetContents)
        self.verticalLayout_6.setObjectName(u"verticalLayout_6")
        self.verticalLayout_6.setContentsMargins(0, 0, 0, 0)
        self.monitor_scollarea.setWidget(self.scrollAreaWidgetContents)

        self.verticalLayout_5.addWidget(self.monitor_scollarea)

        self.horizontalScrollBar = QScrollBar(self.frame_4)
        self.horizontalScrollBar.setObjectName(u"horizontalScrollBar")
        self.horizontalScrollBar.setOrientation(Qt.Horizontal)

        self.verticalLayout_5.addWidget(self.horizontalScrollBar)

        self.splitter.addWidget(self.frame_4)
        self.frame_3 = QFrame(self.splitter)
        self.frame_3.setObjectName(u"frame_3")
        self.frame_3.setEnabled(True)
        sizePolicy3 = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Minimum)
        sizePolicy3.setHorizontalStretch(0)
        sizePolicy3.setVerticalStretch(0)
        sizePolicy3.setHeightForWidth(self.frame_3.sizePolicy().hasHeightForWidth())
        self.frame_3.setSizePolicy(sizePolicy3)
        self.frame_3.setMinimumSize(QSize(0, 0))
        self.frame_3.setMaximumSize(QSize(16777215, 400))
        self.frame_3.setSizeIncrement(QSize(0, 0))
        self.frame_3.setBaseSize(QSize(0, 0))
        self.frame_3.setFrameShape(QFrame.StyledPanel)
        self.frame_3.setFrameShadow(QFrame.Raised)
        self.gridLayout = QGridLayout(self.frame_3)
        self.gridLayout.setObjectName(u"gridLayout")
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.tab_console = QTabWidget(self.frame_3)
        self.tab_console.setObjectName(u"tab_console")
        self.tab_console.setEnabled(True)
        sizePolicy4 = QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Minimum)
        sizePolicy4.setHorizontalStretch(0)
        sizePolicy4.setVerticalStretch(0)
        sizePolicy4.setHeightForWidth(self.tab_console.sizePolicy().hasHeightForWidth())
        self.tab_console.setSizePolicy(sizePolicy4)
        self.tab_console.setMaximumSize(QSize(16777215, 16777215))
        self.tab_console.setElideMode(Qt.ElideLeft)
        self.tab_3 = QWidget()
        self.tab_3.setObjectName(u"tab_3")
        sizePolicy5 = QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
        sizePolicy5.setHorizontalStretch(0)
        sizePolicy5.setVerticalStretch(0)
        sizePolicy5.setHeightForWidth(self.tab_3.sizePolicy().hasHeightForWidth())
        self.tab_3.setSizePolicy(sizePolicy5)
        self.verticalLayout_8 = QVBoxLayout(self.tab_3)
        self.verticalLayout_8.setObjectName(u"verticalLayout_8")
        self.verticalLayout_8.setContentsMargins(4, 4, 4, 4)
        icon6 = QIcon()
        icon6.addFile(u":/icon_w/assets/svg_white/notification.svg", QSize(), QIcon.Normal, QIcon.Off)
        icon6.addFile(u":/icon_b/assets/svg_blue/notification.svg", QSize(), QIcon.Normal, QIcon.On)
        self.tab_console.addTab(self.tab_3, icon6, "")
        self.tab_4 = QWidget()
        self.tab_4.setObjectName(u"tab_4")
        icon7 = QIcon()
        icon7.addFile(u":/icon_w/assets/svg_white/terminal.svg", QSize(), QIcon.Normal, QIcon.Off)
        icon7.addFile(u":/icon_b/assets/svg_blue/terminal.svg", QSize(), QIcon.Normal, QIcon.On)
        icon7.addFile(u":/icon_w/assets/svg_white/terminal.svg", QSize(), QIcon.Disabled, QIcon.Off)
        self.tab_console.addTab(self.tab_4, icon7, "")

        self.gridLayout.addWidget(self.tab_console, 0, 0, 1, 1)

        self.splitter.addWidget(self.frame_3)

        self.verticalLayout_4.addWidget(self.splitter)


        self.horizontalLayout.addWidget(self.right)


        self.verticalLayout.addWidget(self.frame)


        self.retranslateUi(Profiler)

        self.tab_main.setCurrentIndex(0)
        self.tab_console.setCurrentIndex(0)


        QMetaObject.connectSlotsByName(Profiler)
    # setupUi

    def retranslateUi(self, Profiler):
        Profiler.setWindowTitle(QCoreApplication.translate("Profiler", u"\u5b89\u5353\u6027\u80fd", None))
#if QT_CONFIG(tooltip)
        Profiler.setToolTip("")
#endif // QT_CONFIG(tooltip)
        self.cbx_device.setPlaceholderText(QCoreApplication.translate("Profiler", u"\u8bf7\u9009\u62e9\u8bbe\u5907", None))
        self.cbx_app.setPlaceholderText(QCoreApplication.translate("Profiler", u"\u9009\u62e9APP", None))
        self.btn_connect.setText(QCoreApplication.translate("Profiler", u"\u8fde\u63a5", None))
#if QT_CONFIG(tooltip)
        self.btn_open.setToolTip(QCoreApplication.translate("Profiler", u"<html><head/><body><p>\u8bfb\u53d6\u8bb0\u5f55</p><p>\u53ea\u6709\u65ad\u5f00\u8fde\u63a5\u7684\u60c5\u51b5\u4e0b\u624d\u53ef\u4ee5\u8bfb\u53d6\u8bb0\u5f55</p></body></html>", None))
#endif // QT_CONFIG(tooltip)
        self.btn_open.setText(QCoreApplication.translate("Profiler", u"...", None))
#if QT_CONFIG(tooltip)
        self.btn_save.setToolTip(QCoreApplication.translate("Profiler", u"\u4fdd\u5b58\u8bb0\u5f55", None))
#endif // QT_CONFIG(tooltip)
        self.btn_save.setText(QCoreApplication.translate("Profiler", u"...", None))
        self.btn_record.setText(QCoreApplication.translate("Profiler", u"...", None))
        self.btn_record.setProperty("style", QCoreApplication.translate("Profiler", u"danger", None))
        ___qtablewidgetitem = self.tb_device_info.horizontalHeaderItem(0)
        ___qtablewidgetitem.setText(QCoreApplication.translate("Profiler", u"\u5c5e\u6027", None));
        ___qtablewidgetitem1 = self.tb_device_info.horizontalHeaderItem(1)
        ___qtablewidgetitem1.setText(QCoreApplication.translate("Profiler", u"\u503c", None));
        self.btn_copy_info.setText(QCoreApplication.translate("Profiler", u"\u590d\u5236\u4fe1\u606f", None))
        self.tab_main.setTabText(self.tab_main.indexOf(self.tab), QCoreApplication.translate("Profiler", u"\u8bbe\u5907", None))
#if QT_CONFIG(tooltip)
        self.tab_console.setToolTip("")
#endif // QT_CONFIG(tooltip)
        self.tab_console.setTabText(self.tab_console.indexOf(self.tab_3), QCoreApplication.translate("Profiler", u"LogCat", None))
        self.tab_console.setTabText(self.tab_console.indexOf(self.tab_4), QCoreApplication.translate("Profiler", u"Cmd", None))
    # retranslateUi




#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    :   app.py
@Time    :   2022/04/28 19:17:00
@Author  :   Calros Teng 
@Version :   1.0
@Contact :   303359166@qq.com
@License :   (C)Copyright 2017-2018, Xin Yuan Studio
@Desc    :   app全局对象
"""


# here put the import lib
import logging

import pkg_resources
from PySide6.QtWidgets import QApplication

from . import __version__, __author__, __author_email__, pages
from .modules.hot_plug import HotPlugWatcher
from .ui.layout import MainWindow

log = logging.getLogger(__name__)


def about_content():

    about_txt: str = pkg_resources.resource_string(
        __package__, "assets/ABOUT.md"
    ).decode("utf-8")

    doc = about_txt.format(
        __version__=__version__,
        __author__=__author__,
        __author_email__=__author_email__,
    )
    return doc


class PerfcatApplication(QApplication):
    """
    Perfcat App本体
    负责App框架管理

    _extended_summary_

    Args:
        QApplication (_type_): _description_
    """

    def __init__(self, *args):
        super().__init__(*args)

        self.load_stylesheet()
        self.main_win = MainWindow()
        self.main_win.set_about_info(about_content())
        self.main_win.show()

        self._install_pages()

        HotPlugWatcher.install(self)

    @classmethod
    @property
    def instance(cls) -> "PerfcatApplication":
        return QApplication.instance()

    def load_stylesheet(self, path=None):
        if not path:
            stylesheet = pkg_resources.resource_string(
                __package__, "assets/css/default.css"
            ).decode("utf-8")
            log.debug("加载内置stylesheet")
        else:
            with open(path) as f:
                stylesheet = f.read()
            log.debug(f"加载stylesheet：{path}")

        self.setStyleSheet(stylesheet)
        log.debug("加载stylesheet")

    def _install_pages(self):
        w = self.main_win
        for page in pages.register:
            w.add_page(page(w))



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    :   __init__.py
@Time    :   2022/04/29 12:12:58
@Author  :   Calros Teng 
@Version :   1.0
@Contact :   303359166@qq.com
@License :   (C)Copyright 2017-2018, Xin Yuan Studio
@Desc    :   

win系统下的 热拔插监控实现

Qt默认的nativeEvent下，WM_DEVICECHANGE的msg.wParam永远是7，这意味着你只能得到设备变更事件，无法得知是插还是拔。
想要wParam的值正常，你需要win32gui.RegisterDeviceNotification注册系统设备通知。
注册过后WM_DEVICECHANGE的msg.wParam就会在插拔的时候为 win32con.DBT_DEVICEARRIVAL 或  win32con.DBT_DEVICEREMOVECOMPLETE了。
"""

# here put the import lib

import ctypes
from ctypes.wintypes import MSG
import PySide6
import logging
import win32gui_struct
import win32gui, win32con

from typing import Tuple, Union
from PySide6.QtCore import QCoreApplication, QTimer
from PySide6.QtGui import QWindow
from .base import BaseHotPlugNativeEventFilter

log = logging.getLogger(__name__)

# These device GUIDs are from Ioevent.h in the Windows SDK.  Ideally they
# could be collected somewhere for pywin32...
GUID_DEVINTERFACE_USB_DEVICE = "{A5DCBF10-6530-11D2-901F-00C04FB951ED}"


class WinHotPlugNativeEventFilter(BaseHotPlugNativeEventFilter):
    def nativeEventFilter(
        self, eventType: Union[PySide6.QtCore.QByteArray, bytes], message: int
    ) -> Tuple[object, int]:
        if eventType == b"windows_generic_MSG":
            msg = MSG.from_address(int(message))
            if msg.message == win32con.WM_DEVICECHANGE:
                # log.debug(f"设备变更 {msg.message} {msg.wParam} {msg.lParam}")
                # info = win32gui_struct.UnpackDEV_BROADCAST(msg.lParam)
                timer = QTimer(self)
                timer.setSingleShot(True)
                timer.setInterval(1000)
                timer.timeout.connect(lambda: self.device_changed.emit())

                if msg.wParam == win32con.DBT_DEVICEARRIVAL:
                    log.debug("设备插入")
                    timer.timeout.connect(lambda: self.device_added.emit())
                    timer.start()

                if msg.wParam == win32con.DBT_DEVICEREMOVECOMPLETE:
                    log.debug("设备移除")
                    timer.timeout.connect(lambda: self.device_removed.emit())
                    timer.start()

        return False

    def install(self, app: QCoreApplication):

        # 创建一个看不见的窗口用来RegisterDeviceNotification
        # 我们无法从app中获取其主窗口
        self._watcher = QWindow()
        hwnd = self._watcher.winId()

        filter = win32gui_struct.PackDEV_BROADCAST_DEVICEINTERFACE(
            GUID_DEVINTERFACE_USB_DEVICE
        )

        self.h_notify = win32gui.RegisterDeviceNotification(
            hwnd, filter, win32con.DEVICE_NOTIFY_WINDOW_HANDLE
        )

        if self.h_notify == 0:
            log.error(f"RegisterDeviceNotification {ctypes.FormatError()}")

        return super().install(app)

    def uninstall(self, app: QCoreApplication):
        win32gui.UnregisterDeviceNotification(self.h_notify)
        return super().uninstall(app)



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    :   comm_title_bar.py
@Time    :   2022/04/27 18:54:24
@Author  :   Calros Teng 
@Version :   1.0
@Contact :   303359166@qq.com
@License :   (C)Copyright 2017-2018, Xin Yuan Studio
@Desc    :   通用标题栏，完全用PySide6实现窗体移动
"""

# here put the import lib

from PySide6.QtWidgets import QMainWindow
from PySide6.QtCore import Qt
from PySide6.QtGui import QMouseEvent, QCursor
from .base_title_bar import BaseTitleBar


class CommTitleBar(BaseTitleBar):
    def __init__(self, parent: QMainWindow) -> None:
        super().__init__(parent)
        self._handle_move_window()

    def _handle_move_window(self):
        main_win: QMainWindow = self.window()

        def moveWindow(event: QMouseEvent):
            if main_win.isMaximized():
                main_win.showNormal()
                cur_x = main_win.pos().x()
                cur_y = event.globalPos().y() - QCursor.pos().y()
                main_win.move(cur_x, cur_y)

            if event.buttons() == Qt.LeftButton:
                main_win.move(main_win.pos() + event.globalPos() - self._dragPos)
                self._dragPos = event.globalPos()
                event.accept()

        self.logo.mouseMoveEvent = moveWindow
        self.lb_title.mouseMoveEvent = moveWindow

    def mousePressEvent(self, event: QMouseEvent) -> None:
        self._dragPos = event.globalPos()
        return super().mousePressEvent(event)



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    :   cpu_monitor.py
@Time    :   2022/05/09 18:20:33
@Author  :   Calros Teng 
@Version :   1.0
@Contact :   303359166@qq.com
@License :   (C)Copyright 2017-2018, Xin Yuan Studio
@Desc    :   emm...

获取cpu使用率和app cpu使用率的途径有很多
[1] 通过解析top命令
[2] 通过解析 proc/stat， top其实也是解析proc/stat
[2] 通过dumpsys cpuinfo，但是dumpsys不是实时的，他是间隔采样的

[1] github上的很多开源项目都是用top命令解析来获取cpu使用率，这个方法最简单，所以我还是决定用这个
"""

# here put the import lib

import logging

from PySide6.QtCharts import QLineSeries

from perfcat.modules.profiler.cpu import get_all_cpu_cur_freq, normalize_factor, get_all_cpu_state
from ppadb.device import Device
from .base.chart import MonitorChart

from ppadb.device import Device
from ppadb.plugins.device.cpustat import TotalCPUStat

log = logging.getLogger(__name__)


def __cpu_max_freq(dev: Device) -> list:
    count = dev.cpu_count()
    freq = []
    for index in range(count):
        cmd_root = f"cat /sys/devices/system/cpu/cpu{index}/cpufreq"
        max = dev.shell(f"{cmd_root}/cpuinfo_max_freq")

        freq.append(int(max))

    return freq


class CpuMonitor(MonitorChart):
    def __init__(self, parent=None):
        super().__init__(
            y_axis_name="%",
            parent=parent,
        )
        self.setObjectName("CPU")
        self.pid = None
        self.last_total_cpu_state = None
        self.last_pid_cpu_state = None
        self.last_all_cpu_state = None

        self.cpu_count = None

        self._sample_data = {}

        self.create_series("TotalCPU(标准化)", QLineSeries(self), lambda v: f"{v}%")
        self.create_series("AppCPU(标准化)", QLineSeries(self), lambda v: f"{v}%")

    def reset_series_data(self):
        self.pid = None
        self.last_total_cpu_state = None
        self.last_pid_cpu_state = None
        self.last_all_cpu_state = None
        self._sample_data = {}
        return super().reset_series_data()

    def sample(self, sec: int, device: Device, package_name: str):
        # 我们直接取top的数据，因此cpu占用是未规范化的
        # 为规范化的CPU占用值会导致一个问题：
        # 当你在A设备上测试采集到的峰值，跟B设备上测试采集到的峰值不一致。
        # 可能A设备的平均峰值更高

        pid_str = device.shell(f"pidof {package_name}")
        if pid_str:
            self.pid = int(pid_str)
        else:
            self.pid = None

        # 归一化因子，归一化CPU占用
        # 参考：https://blog.gamebench.net/measuring-cpu-usage-in-mobile-devices
        factor = normalize_factor(device)

        # 参考 SoloPi的算法

        # 采集cpu总占用
        total_cpu_usage = 0
        total_cpu_usage_normalized = 0
        if self.last_total_cpu_state is None:
            self.last_total_cpu_state = device.get_total_cpu()
        else:
            cur_total_cpu = device.get_total_cpu()
            cpu_diff:TotalCPUStat = cur_total_cpu - self.last_total_cpu_state
            total_cpu_usage = 100 * (cpu_diff.user + cpu_diff.system) / cpu_diff.total()
            total_cpu_usage = round(total_cpu_usage,2)
            self.last_total_cpu_state = cur_total_cpu

        total_cpu_usage_normalized = round(total_cpu_usage * factor,2)
        self.add_point("TotalCPU(标准化)", sec, total_cpu_usage_normalized)


        # 采集pid占用
        app_cpu_usage = 0
        app_cpu_usage_normalized = 0
        if self.pid is None:  # 如果app没启动，那么就记录0占用
            self.add_point("AppCPU(标准化)", sec, 0)
        else:
            # 启动了就从top里面找
            cur_pid_cpu = device.get_pid_cpu(self.pid)
            if self.last_pid_cpu_state is None:
                self.last_pid_cpu_state = cur_pid_cpu
            else:
                pid_diff = cur_pid_cpu - self.last_pid_cpu_state
                app_cpu_usage = 100 * pid_diff.total() / cpu_diff.total()
                app_cpu_usage = round(app_cpu_usage,2)
                self.last_pid_cpu_state = cur_pid_cpu
            app_cpu_usage_normalized = round(app_cpu_usage*factor,2)
            self.add_point("AppCPU(标准化)", sec, app_cpu_usage_normalized)

        # 采集所有cpu占用
        self.cpu_count = self.cpu_count or device.cpu_count()
        all_cpu_cur_freq = get_all_cpu_cur_freq(device)
        all_cpu_usage = {i:0 for i in range(self.cpu_count)}
        if self.last_all_cpu_state is None:
            self.last_all_cpu_state = get_all_cpu_state(device)
        else:
            all_cpu_state = get_all_cpu_state(device)
            for index, cpu_state in all_cpu_state.items():
                last_cpu_state = self.last_all_cpu_state[index]
                cpu_diff:TotalCPUStat = cpu_state-last_cpu_state
                cpu_usage = 100* (cpu_diff.user+cpu_diff.system)/cpu_diff.total()
                all_cpu_usage[index] = round(cpu_usage,2)
            self.last_all_cpu_state = all_cpu_state

        self._sample_data[sec] = {
            "AppCPU": app_cpu_usage,
            "TotalCPU":total_cpu_usage,
            "AppCPUNormalized":app_cpu_usage_normalized,
            "TotalCPUNormalized":total_cpu_usage_normalized,
            "AllCPUCurFreq": all_cpu_cur_freq,
            "AllCPUUsage":all_cpu_usage,
            "AllCPUUsageNormalized":{index:round(usage* factor,2) for index, usage in all_cpu_usage.items()}
        }



    def to_dict(self, all: bool = True) -> dict:
        if all:
            return self._sample_data
        else:
            start = self.record_range[0]
            end = self.record_range[1]

            data = {}
            for k,v in self._sample_data.items():
                if start <= k <= end:
                    data[k] = v
            return data


    def from_dict(self, data: dict):
        for sec, data_table in data.items():
            app_cpu_value = data_table["AppCPUNormalized"]
            total_cpu_value = data_table["TotalCPUNormalized"]

            if app_cpu_value:
                self.add_point("AppCPU(标准化)", int(sec), app_cpu_value)

            if total_cpu_value:
                self.add_point("TotalCPU(标准化)", int(sec), total_cpu_value)

            self.flush()



from textwrap import wrap
import time
import logging
from functools import wraps
from typing import Callable

log = logging.getLogger(__name__)


def get_time(func: Callable):
    @wraps(func)
    def wrapper(*args, **kwargs):
        s_time = time.time()
        res = func(*args, **kwargs)
        e_time = time.time()
        log.debug(f"{func.__name__} 耗时：{e_time-s_time}")
        return res

    return wrapper



import logging
import sys
import traceback


def log_unhandled_exception(*exc_info):
    text = "".join(traceback.format_exception(*exc_info))
    logging.exception("未捕获的异常: {0}".format(text))


sys.excepthook = log_unhandled_exception

logging.basicConfig(
    level=logging.DEBUG,
    format="%(asctime)s - [%(levelname)s] - %(name)s - %(filename)s:%(lineno)d - %(message)s",
    handlers=[
        logging.FileHandler("debug.log", mode="w", encoding="utf-8"),
        logging.StreamHandler(sys.stdout),
    ],
)



import datetime
from typing import List
from openpyxl import Workbook
from openpyxl.cell import Cell
from openpyxl.styles.fills import PatternFill
from openpyxl.styles import borders
from openpyxl.comments import Comment
from openpyxl.worksheet.worksheet import Worksheet

from openpyxl.chart.line_chart import LineChart
from openpyxl.chart.reference import Reference

THIN_SIDE = borders.Side(border_style=borders.BORDER_THIN)
BORDER = borders.Border(
    top=THIN_SIDE, left=THIN_SIDE, right=THIN_SIDE, bottom=THIN_SIDE
)
TAG_FILL = PatternFill("solid", start_color="c0504d")

TITLE_FILL = PatternFill("solid", start_color="f79646")
CONTENT_FILL = PatternFill("solid", start_color="f2dcdb")


def export(app_name: str, data: dict, filename: str):
    wb = Workbook()
    ws = wb.active
    ws.title = "报告"
    cur_row = 1

    c_date_label: Cell = ws["A1"]
    c_date_text: Cell = ws["B1"]
    c_pkg_name_label: Cell = ws["A2"]
    c_pkg_name_text: Cell = ws["B2"]

    c_date_label.value = "生成日期"
    c_date_label.fill = TAG_FILL
    c_date_label.border = BORDER

    c_date_text.value = datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")
    c_date_text.fill = CONTENT_FILL
    c_date_text.border = BORDER

    c_pkg_name_label.value = "包名"
    c_pkg_name_label.fill = TAG_FILL
    c_pkg_name_label.border = BORDER

    c_pkg_name_text.value = app_name
    c_pkg_name_text.fill = CONTENT_FILL
    c_pkg_name_text.border = BORDER

    c_device_info_tag: Cell = ws["A4"]
    c_device_info_tag.fill = TAG_FILL
    c_device_info_tag.value = "设备信息"

    cur_row = 4

    device_info: dict = data["device_info"]

    for index, key in enumerate(device_info.keys()):
        cur_row += 1
        c_title = ws.cell(cur_row, 1, key)
        c_content = ws.cell(cur_row, 2, device_info[key])
        c_title.fill = TITLE_FILL
        c_title.border = BORDER
        c_content.fill = CONTENT_FILL
        c_content.border = BORDER

    cur_row += 1

    # 统计

    # 帧率
    stat_data = {}
    fps_data = data["data"]["FPS"]
    record_length = len(fps_data.keys())
    fps_list = [data["fps"] for data in fps_data.values()]
    # 平均帧率
    fps_avg = sum(fps_list) / record_length
    # 帧率18以上比例
    fps_gt_18 = len(list(filter(lambda fps: fps >= 18, fps_list))) / record_length
    # 帧率25以上比例
    fps_gt_25 = len(list(filter(lambda fps: fps >= 25, fps_list))) / record_length

    # 方差
    fps_var = sum([(fps - fps_avg) ** 2 for fps in fps_list]) / (record_length - 1.0)

    # 降帧频率（每小时 降帧次数）
    fps_drop = (
        len(
            list(
                filter(
                    lambda diff: diff > 8,
                    [
                        abs(fps_list[i] - fps_list[i - 1])
                        for i in range(1, record_length)
                    ],
                )
            )
        )
        / record_length
        * 3600
    )

    # Jank率 （每10分钟卡顿次数）
    fps_jank = (
        sum([data["jank"] for data in fps_data.values()]) / record_length * 10 * 60
    )
    fps_big_jank = (
        sum([data["big_jank"] for data in fps_data.values()]) / record_length * 10 * 60
    )

    stat_data["平均帧率"] = (round(fps_avg), "具体看游戏锁帧的帧率")
    stat_data["帧率18以上比例（%）"] = (round(fps_gt_18 * 100, 2), "90%以上最佳")
    stat_data["帧率25以上比例（%）"] = (round(fps_gt_25 * 100, 2), "80%以上最佳")
    stat_data["帧率方差"] = (round(fps_var, 2), "值越低越稳定，0表示极其稳定")
    stat_data["降帧频率（次/小时）"] = (round(fps_drop), "值越大意味着掉帧越频繁，但是不代表有卡顿")
    stat_data["卡顿率（次/10分钟）"] = (round(fps_jank), "值越大意味着体验越不流畅")
    stat_data["大卡顿（次/10分钟)"] = (round(fps_big_jank), "值越大意味着肉眼可见的打断体验的卡顿明显")

    # FrameTime大于100ms的概率
    fps_frametime_gt_100 = 0
    frametime_count = 0
    for data_value in fps_data.values():
        framtimes: list = data_value["*frametimes"]
        fps_frametime_gt_100 += len(list(filter(lambda ft: ft > 100, framtimes)))
        frametime_count += len(framtimes)

    fps_frametime_gt_100 /= frametime_count

    fps_frametime_gt_100_rate = fps_frametime_gt_100 * 60 * 3600

    stat_data["FrameTime大于100ms的比例（%）"] = (
        round(fps_frametime_gt_100 * 100, 2),
        "帧间隔大于100ms比例越高意味着渲染压力越大\n算法不是很准，仅供参考",
    )
    stat_data["FrameTime大于100ms的频率（次/小时）"] = (
        round(fps_frametime_gt_100_rate, 2),
        "帧间隔大于100ms的概率越高意味着渲染影响到流畅体验\n算法不是很准，仅供参考",
    )

    # 内存
    mem_data = data["data"]["Memory"]
    pss_list = [mem["PSS"] for mem in mem_data.values()]
    swap_list = [mem["SwappedDirty"] for mem in mem_data.values()]
    pss_swap_list = [pss_list[i] + swap_list[i] for i in range(record_length)]

    avg_pss = sum(pss_list) / record_length
    max_pss = max(pss_list)
    max_pss_swap = max(pss_swap_list)

    stat_data["平均内存占用(MB)"] = (round(avg_pss, 2), "平均PSS")
    stat_data["峰值内存占用(MB)"] = (round(max_pss, 2), "峰值PSS")
    stat_data["峰值PSS+SWAP(MB)"] = (round(max_pss_swap, 2), "峰值PSS+SWAP")

    # CPU
    cpu_data = data["data"]["CPU"]
    app_cpu_list = [cpu["AppCPU"] for cpu in cpu_data.values()]
    app_cpu_n_list = [cpu["AppCPUNormalized"] for cpu in cpu_data.values()]
    avg_app_cpu = sum(app_cpu_list) / record_length
    app_cpu_lt_60 = len(list(filter(lambda v: v <= 60, app_cpu_list))) / record_length
    app_cpu_lt_80 = len(list(filter(lambda v: v <= 80, app_cpu_list))) / record_length

    avg_app_cpu_n = sum(app_cpu_n_list) / record_length
    app_cpu_n_lt_60 = (
        len(list(filter(lambda v: v <= 60, app_cpu_n_list))) / record_length
    )
    app_cpu_n_lt_80 = (
        len(list(filter(lambda v: v <= 80, app_cpu_n_list))) / record_length
    )

    stat_data["平均AppCPU占用（%）"] = (round(avg_app_cpu, 2), "")
    stat_data["平均AppCPU小于60%的比例（%）"] = (round(app_cpu_lt_60 * 100, 2), "")
    stat_data["平均AppCPU小于80%的比例（%）"] = (round(app_cpu_lt_80 * 100, 2), "")
    stat_data["平均AppCPU占用（标准化%）"] = (round(avg_app_cpu_n, 2), "")
    stat_data["平均AppCPU小于60%的比例（标准化%）"] = (round(app_cpu_n_lt_60 * 100, 2), "")
    stat_data["平均AppCPU小于80%的比例（标准化%）"] = (round(app_cpu_n_lt_80 * 100, 2), "")

    cur_row += 1
    c_stat_tag: Cell = ws.cell(cur_row, 1)
    c_stat_tag.fill = TAG_FILL
    c_stat_tag.value = "统计"

    for index, key in enumerate(stat_data.keys()):
        cur_row += 1
        c_title = ws.cell(cur_row, 1, key)
        c_title.fill = TITLE_FILL
        c_title.border = BORDER
        c_title.comment = Comment(stat_data[key][1], "perfcat")

        c_content = ws.cell(cur_row, 2, stat_data[key][0])
        c_content.fill = CONTENT_FILL
        c_content.border = BORDER

    # 调整列宽
    adjust_width(ws)

    ws_detail = wb.create_sheet("详细数据")

    records = data["data"]

    record_range = data["record_range"]
    title_row = 1

    table = {}

    for tick in range(record_range[0], record_range[1]):
        table[tick] = {}
        for record_name, record_dict in records.items():
            if not record_dict:
                continue

            record_data = record_dict[tick]
            for title, value in record_data.items():
                if isinstance(value, dict):
                    for k, v in value.items():
                        table[tick][f"{title}{k}"] = v
                elif isinstance(value, list):
                    for index, v in enumerate(value):
                        table[tick][f"{title}{index}"] = v
                else:
                    table[tick][title] = value

    if table:
        titles = list(table.values())[0].keys()
        for col, title in enumerate(titles):
            c_title = ws_detail.cell(title_row, col + 2, title)
            c_title.fill = TITLE_FILL
            c_title.border = BORDER

        c_title_sec = ws_detail.cell(title_row, 1, "秒")
        c_title_sec.fill = TITLE_FILL
        c_title_sec.border = BORDER

        for row, row_data in enumerate(table.values()):
            cell = ws_detail.cell(title_row + row + 1, 1, row)  # 写入秒
            cell.fill = CONTENT_FILL
            cell.border = BORDER
            for col, col_name in enumerate(row_data.keys()):
                cell = ws_detail.cell(title_row + row + 1, col + 2, row_data[col_name])
                cell.fill = CONTENT_FILL
                cell.border = BORDER

        adjust_width(ws_detail)

        # FPS chart
        selected_titles = ["fps", "jank", "big_jank"]
        chart = create_chart(ws_detail, selected_titles, titles, "FPS", "")
        ws.add_chart(chart, "A44")

        # CPU chart
        selected_titles = ["AppCPU", "TotalCPU"]
        chart = create_chart(ws_detail, selected_titles, titles, "CPU占用", "%")
        ws.add_chart(chart, "A74")

        # MEM chart
        selected_titles = [
            "PSS",
            "PrivateDirty",
            "PrivateClean",
            "SwappedDirty",
            "HeapSize",
            "HeapAlloc",
            "HeapFree",
        ]
        chart = create_chart(ws_detail, selected_titles, titles, "内存占用", "%")
        ws.add_chart(chart, "A104")

        # Temp chart
        selected_titles = ["整体温度", "CPU温度", "GPU温度", "NPU温度", "电池温度"]
        chart = create_chart(ws_detail, selected_titles, titles, "温度", "%")
        ws.add_chart(chart, "A134")

    wb.save(filename)
    wb.close()


def adjust_width(ws: Worksheet):
    for col in ws.columns:
        col_name = col[0].column_letter
        max_length = max([len(str(cell.value)) for cell in col])
        adjust_width = (max_length + 2) * 1.2
        ws.column_dimensions[col_name].width = adjust_width


def create_chart(
    ws_detail: Worksheet,
    selected_titles: List[str],
    titles: List[str],
    chart_name: str,
    y_axis_name: str,
):
    chart = LineChart()
    chart.title = chart_name
    chart.legend.position = "r"
    chart.y_axis.title = y_axis_name
    chart.width = 40
    chart.height = 12
    titles = list(titles)
    cols = [titles.index(selected) + 2 for selected in selected_titles]

    for col in cols:
        data_ref = Reference(
            ws_detail, min_col=col, max_col=col, min_row=1, max_row=ws_detail.max_row
        )
        chart.add_data(data_ref, titles_from_data=True)

    return chart



# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'mainwindow.ui'
##
## Created by: Qt User Interface Compiler version 6.4.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QDate, QDateTime, QLocale,
    QMetaObject, QObject, QPoint, QRect,
    QSize, QTime, QUrl, Qt)
from PySide6.QtGui import (QBrush, QColor, QConicalGradient, QCursor,
    QFont, QFontDatabase, QGradient, QIcon,
    QImage, QKeySequence, QLinearGradient, QPainter,
    QPalette, QPixmap, QRadialGradient, QTransform)
from PySide6.QtWidgets import (QApplication, QFrame, QGridLayout, QHBoxLayout,
    QLayout, QMainWindow, QSizePolicy, QStackedWidget,
    QVBoxLayout, QWidget)
import asset_rc

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        if not MainWindow.objectName():
            MainWindow.setObjectName(u"MainWindow")
        MainWindow.resize(1400, 814)
        MainWindow.setMinimumSize(QSize(1200, 540))
        icon = QIcon()
        icon.addFile(u":/icon_b/assets/svg_blue/xing.svg", QSize(), QIcon.Normal, QIcon.Off)
        MainWindow.setWindowIcon(icon)
        MainWindow.setWindowOpacity(1.000000000000000)
        MainWindow.setStyleSheet(u"*{\n"
"    border-radius:8;\n"
"    color:#6c7c96;\n"
"}\n"
"\n"
"#container {\n"
"background-color:#2c313c;\n"
"}\n"
"\n"
"#left_menu_frame{\n"
"background-color:#1b1e23;\n"
"}\n"
"\n"
"#title_bar_frame{\n"
"background-color:#343b48;\n"
"}\n"
"\n"
"#status_bar_frame{\n"
"background-color:#343b48;\n"
"}\n"
"\n"
"#content_frame{\n"
"background-color:#343b48;\n"
"}\n"
"\n"
"#setting_frame {\n"
"background-color:#3c4454;\n"
"}\n"
"\n"
"#left_column_frame {\n"
"background-color:#343b48;\n"
"}\n"
"\n"
"/* \u4fa7\u8fb9\u83dc\u5355\u680f\u6837\u5f0f */\n"
"\n"
"#LeftMenu {\n"
"background-color: #005dfd;\n"
"}\n"
"\n"
"#LeftMenu QPushButton {\n"
"background-color:#1b1e23;\n"
"height:40;\n"
"text-align:left;\n"
"padding-left:15;\n"
"padding-top:2;\n"
"padding-bottom:2;\n"
"color:#6b7884;\n"
"}\n"
"\n"
"#LeftMenu QPushButton:hover{\n"
"background-color:#21252d;\n"
"}\n"
"\n"
"#LeftMenu QPushButton:pressed{\n"
"background-color:#2c313c;\n"
"}\n"
"\n"
"#LeftMenu QPushButton:checked{\n"
"background-color:#2c313c;\n"
"}\n"
""
                        "\n"
"#LeftMenu QPushButton:focus{\n"
"border:none;\n"
"}\n"
"\n"
"\n"
"#LeftMenu #bottom{\n"
"border-top:1 solid #272c36;\n"
"border-radius: 0;\n"
"}\n"
"\n"
"#LeftMenu #nav_menu {\n"
"border-top:1 solid #272c36;\n"
"border-radius: 0\uff1b\n"
"}\n"
"\n"
"#LeftMenu #scrollArea,#scrollAreaWidgetContents_3{\n"
"background-color:#1b1e23;\n"
"border:none;\n"
"}\n"
"\n"
"#LeftMenu #btn_toggle:checked{\n"
"background-color:#21252d;\n"
"}\n"
"\n"
"\n"
"/* \u6807\u9898\u680f\u6837\u5f0f */\n"
"\n"
"#TitleBar #bg{\n"
"background-color:#343b48;\n"
"border-radius:8;\n"
"}\n"
"\n"
"#TitleBar #logo {\n"
"border: 1px solid #3c4454;\n"
"padding-right:10px;\n"
"border-top:none;\n"
"border-bottom:none;\n"
"border-left:none;\n"
"margin-right:5px;\n"
"border-radius:0;\n"
"}\n"
"\n"
"#TitleBar  #logo_title{\n"
"color:#77b3f1;\n"
"font-size:20px;\n"
"font-weight:bold;\n"
"}\n"
"\n"
"#TitleBar  #lb_title{\n"
"font-size:14px;\n"
"color:#6c7c96;\n"
"}\n"
"\n"
"#TitleBar  QToolButton{\n"
"background-color:#343b48;\n"
"border:none;\n"
""
                        "border-radius:4;\n"
"padding: 4;\n"
"}\n"
"\n"
"#TitleBar QToolButton:hover,\n"
"#TitleBar QToolButton:checked{\n"
"background-color:#3c4454;\n"
"}\n"
"\n"
"\n"
"#TitleBar QToolButton:pressed{\n"
"background-color:#e2e9f7;\n"
"}\n"
"\n"
"#TitleBar #tool{\n"
"border:1px solid #3c4454;\n"
"border-top:none;\n"
"border-bottom:none;\n"
"margin-right:5px;\n"
"border-radius:0;\n"
"}\n"
"\n"
"\n"
"#LeftColumn{\n"
"background-color:#343b48;\n"
"}\n"
"\n"
"#LeftColumn #top{\n"
"background-color: #3c4454;\n"
"}\n"
"\n"
"#leftColumn #icon{\n"
"\n"
"}\n"
"\n"
"#LeftColumn #title{\n"
"color:#6c7c96;\n"
"}\n"
"\n"
"#LeftColumn QToolButton{\n"
"border:none;\n"
"padding:4;\n"
"background-color: #3c4454;\n"
"}\n"
"\n"
"#LeftColumn #btn_close:hover{\n"
"background-color:#343b48;\n"
"}\n"
"\n"
"#LeftColumn #btn_close:pressed{\n"
"background-color:#1b1e23;\n"
"}\n"
"\n"
"\n"
"/* \u901a\u7528\u63a7\u4ef6 */\n"
"\n"
"QToolTip { \n"
"color:#6b7884;\n"
"background-color: #1b1e23; \n"
"border: 0px; \n"
"border-left: 2px solid #4f9fee;\n"
""
                        "}\n"
"\n"
"QGroupBox{\n"
"	border: 2px solid gray; \n"
"    border-radius: 3px; \n"
"    margin:10;\n"
"}\n"
"\n"
"QGroupBox::title { \n"
"    subcontrol-position: center top; /* position at the top left*/ \n"
"	subcontrol-origin: border;\n"
"	margin-top:-20px;\n"
"\n"
"}\n"
"\n"
"/* Button */\n"
"QAbstractButton{\n"
"background-color:#1b1e23;\n"
"border:none;\n"
"border-radius:4;\n"
"padding: 4;\n"
"outline:none;\n"
"}\n"
"\n"
"QAbstractButton:hover,\n"
"QAbstractButton:checked{\n"
"background-color:#21252d;\n"
"}\n"
"\n"
"\n"
"QAbstractButton:pressed{\n"
"background-color:#272c36;\n"
"}\n"
"\n"
"QAbstractButton:disabled{\n"
"background-color: #272c36;\n"
"}\n"
"\n"
"QAbstractButton:checked{\n"
"background-color:#568af2;\n"
"color:black;\n"
"}\n"
"\n"
"QAbstractButton:focus{\n"
"border: 2px solid #568af2;\n"
"}\n"
"\n"
"QAbstractButton[style~='success']:checked{\n"
"    background-color: #67c23a;\n"
"}\n"
"QAbstractButton[style~='warning']:checked{\n"
"    background-color: #e6a23c;\n"
"}\n"
"QAbstractButton["
                        "style~='danger']:checked{\n"
"    background-color: #f56c6c;\n"
"}\n"
"QAbstractButton[style~='info']:checked{\n"
"    background-color: #909399;\n"
"}\n"
"\n"
"\n"
"/* CheckBox */\n"
"\n"
"QCheckBox::indicator{\n"
"    border:2px solid #6c7c96;\n"
"    border-radius: 2px;\n"
"    width:10px;\n"
"    height:10px;\n"
"    margin-left:8px;\n"
"}\n"
"\n"
"QCheckBox::indicator:checked{\n"
"    border:2px solid black;\n"
"    image: url(:/icon/assets/svg/checkmark.svg);\n"
"}\n"
"\n"
"QRadioButton::indicator{\n"
"    border:1px solid #6c7c96;\n"
"    background-color:#6c7c96;\n"
"    border-radius: 4px;\n"
"    width:10px;\n"
"    height:10px;\n"
"    margin-left:8px;\n"
"}\n"
"\n"
"QRadioButton::indicator:checked{\n"
"    border:1px solid #fff;\n"
"    background-color:black;\n"
"}\n"
"\n"
"/* TextEdit */\n"
"QPlainTextEdit,\n"
"QTextEdit,\n"
"QLineEdit{\n"
"    background-color: #1b1e23;\n"
"    padding:8px;\n"
"}\n"
"\n"
"QPlainTextEdit:focus,\n"
"QTextEdit:focus,\n"
"QLineEdit:focus{\n"
"    border: 2px solid #"
                        "568af2;\n"
"}\n"
"\n"
"QPlainTextEdit:read-only,\n"
"QTextEdit:read-only,\n"
"QLineEdit:read-only{\n"
"    border:none;\n"
"}\n"
"\n"
"/* ProgressBar */\n"
"QProgressBar{\n"
"    background-color: #1b1e23;\n"
"    text-align:center;\n"
"    font-weight: bold;\n"
"}\n"
"\n"
"QProgressBar::chunk:horizontal{\n"
"    background-color: #4f9fee;\n"
"    border-radius: 8px;\n"
"    border-top-right-radius: 0;\n"
"    border-bottom-right-radius:0;\n"
"}\n"
"QProgressBar::chunk:vertical{\n"
"    background-color: #4f9fee;\n"
"    border-radius: 8px;\n"
"    border-top-left-radius: 0;\n"
"    border-top-right-radius:0;\n"
"}\n"
"\n"
"\n"
"/* ScrollBar */\n"
"QScrollBar:horizontal{\n"
"    background-color: #2c313c;\n"
"    border-radius: 0;\n"
"    border:none;\n"
"    max-height: 8px;\n"
"}\n"
"\n"
"QScrollBar::handle:horizontal{\n"
"    background-color:#568af2;\n"
"    border-radius:4px;\n"
"    min-width: 25px;\n"
"}\n"
"\n"
"QScrollBar::add-page:horizontal{\n"
"    background-color:none;\n"
"}\n"
"QScrollBar::sub-p"
                        "age:horizontal{\n"
"    background-color:none;\n"
"}\n"
"\n"
"QScrollBar::add-line:horizontal{\n"
"    background-color:#272c36;\n"
"    border:none;\n"
"    width:0px;\n"
"    border-top-right-radius: 4px;\n"
"    border-bottom-right-radius: 4px;\n"
"    subcontrol-posistion:right;\n"
"    subcontrol-origin:margin;\n"
"}\n"
"QScrollBar::sub-line:horizontal{\n"
"    background-color:#272c36;\n"
"    border:none;\n"
"    width:0px;\n"
"    border-top-right-radius: 4px;\n"
"    border-bottom-right-radius: 4px;\n"
"    subcontrol-posistion:right;\n"
"    subcontrol-origin:margin;\n"
"}\n"
"\n"
"/* Vertical */\n"
"QScrollBar:vertical{\n"
"    background-color: #2c313c;\n"
"    border-radius: 0;\n"
"    border:none;\n"
"    max-width: 8px;\n"
"}\n"
"\n"
"QScrollBar::handle:vertical{\n"
"    background-color:#568af2;\n"
"    border-radius:4px;\n"
"    min-height: 25px;\n"
"}\n"
"\n"
"QScrollBar::add-page:vertical{\n"
"    background-color:none;\n"
"}\n"
"QScrollBar::sub-page:vertical{\n"
"    background-color:none;\n"
""
                        "}\n"
"\n"
"QScrollBar::add-line:vertical{\n"
"    background-color:#272c36;\n"
"    border:none;\n"
"    width:0px;\n"
"    border-top-right-radius: 4px;\n"
"    border-top-left-radius: 4px;\n"
"    subcontrol-posistion:right;\n"
"    subcontrol-origin:margin;\n"
"}\n"
"QScrollBar::sub-line:vertical{\n"
"    background-color:#272c36;\n"
"    border:none;\n"
"    width:0px;\n"
"    border-top-right-radius: 4px;\n"
"    border-top-left-radius: 4px;\n"
"    subcontrol-posistion:right;\n"
"    subcontrol-origin:margin;\n"
"}\n"
"\n"
"\n"
"/* Slider */\n"
"\n"
"QSlider:horizontal{\n"
"    margin:8;\n"
"}\n"
"\n"
"QSlider::groove:horizontal{\n"
"    background-color: #1b1e23;\n"
"    border-radius: 4px;\n"
"    margin:0px;\n"
"    height: 10px;\n"
"}\n"
"QSlider::groove:horizontal:hover{\n"
"    background-color: #21252d;\n"
"}\n"
"\n"
"QSlider::handle:horizontal{\n"
"    border:none;\n"
"    height:16px;\n"
"    width:16px;\n"
"    margin: -3px;\n"
"    border-radius: 8px;\n"
"    background-color: #4f9fee;\n"
"}\n"
""
                        "\n"
"QSlider:vertical{\n"
"    margin:8;\n"
"}\n"
"\n"
"QSlider::groove:vertical{\n"
"    background-color: #1b1e23;\n"
"    border-radius: 4px;\n"
"    margin:0px;\n"
"    width: 10px;\n"
"}\n"
"QSlider::groove:vertical:hover{\n"
"    background-color: #21252d;\n"
"}\n"
"\n"
"QSlider::handle:vertical{\n"
"    border:none;\n"
"    height:16px;\n"
"    width:16px;\n"
"    margin: -3px;\n"
"    border-radius: 8px;\n"
"    background-color: #4f9fee;\n"
"}\n"
"")
        self.centralwidget = QWidget(MainWindow)
        self.centralwidget.setObjectName(u"centralwidget")
        self.centralwidget.setMaximumSize(QSize(16777215, 16777215))
        self.centralwidget.setStyleSheet(u"")
        self.gridLayout = QGridLayout(self.centralwidget)
        self.gridLayout.setObjectName(u"gridLayout")
        self.gridLayout.setContentsMargins(2, 2, 2, 2)
        self.container = QFrame(self.centralwidget)
        self.container.setObjectName(u"container")
        self.container.setMinimumSize(QSize(0, 0))
        self.container.setStyleSheet(u"")
        self.container.setFrameShape(QFrame.StyledPanel)
        self.container.setFrameShadow(QFrame.Raised)
        self.container.setLineWidth(1)
        self.horizontalLayout = QHBoxLayout(self.container)
        self.horizontalLayout.setSpacing(5)
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.horizontalLayout.setContentsMargins(5, 5, 5, 5)
        self.left_menu_frame = QFrame(self.container)
        self.left_menu_frame.setObjectName(u"left_menu_frame")
        sizePolicy = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.left_menu_frame.sizePolicy().hasHeightForWidth())
        self.left_menu_frame.setSizePolicy(sizePolicy)
        self.left_menu_frame.setMinimumSize(QSize(50, 0))
        self.left_menu_frame.setMaximumSize(QSize(240, 16777215))
        self.left_menu_frame.setStyleSheet(u"")
        self.left_menu_frame.setFrameShape(QFrame.StyledPanel)
        self.left_menu_frame.setFrameShadow(QFrame.Raised)
        self.left_menu_frame.setLineWidth(1)
        self.verticalLayout_3 = QVBoxLayout(self.left_menu_frame)
        self.verticalLayout_3.setObjectName(u"verticalLayout_3")
        self.verticalLayout_3.setContentsMargins(2, 2, 2, 2)

        self.horizontalLayout.addWidget(self.left_menu_frame)

        self.left_column_frame = QFrame(self.container)
        self.left_column_frame.setObjectName(u"left_column_frame")
        self.left_column_frame.setMinimumSize(QSize(0, 0))
        self.left_column_frame.setMaximumSize(QSize(0, 16777215))
        self.left_column_frame.setFrameShape(QFrame.StyledPanel)
        self.left_column_frame.setFrameShadow(QFrame.Raised)
        self.verticalLayout_2 = QVBoxLayout(self.left_column_frame)
        self.verticalLayout_2.setObjectName(u"verticalLayout_2")
        self.verticalLayout_2.setContentsMargins(0, 0, 0, 0)

        self.horizontalLayout.addWidget(self.left_column_frame)

        self.app_frame = QFrame(self.container)
        self.app_frame.setObjectName(u"app_frame")
        sizePolicy.setHeightForWidth(self.app_frame.sizePolicy().hasHeightForWidth())
        self.app_frame.setSizePolicy(sizePolicy)
        self.app_frame.setFrameShape(QFrame.StyledPanel)
        self.app_frame.setFrameShadow(QFrame.Raised)
        self.verticalLayout = QVBoxLayout(self.app_frame)
        self.verticalLayout.setSpacing(6)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.verticalLayout.setSizeConstraint(QLayout.SetMaximumSize)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.title_bar_frame = QFrame(self.app_frame)
        self.title_bar_frame.setObjectName(u"title_bar_frame")
        self.title_bar_frame.setMinimumSize(QSize(0, 40))
        self.title_bar_frame.setMaximumSize(QSize(16777215, 40))
        self.title_bar_frame.setStyleSheet(u"")
        self.title_bar_frame.setFrameShape(QFrame.NoFrame)
        self.title_bar_frame.setFrameShadow(QFrame.Raised)
        self.title_bar_frame.setLineWidth(8)
        self.title_bar_frame.setMidLineWidth(10)
        self.verticalLayout_4 = QVBoxLayout(self.title_bar_frame)
        self.verticalLayout_4.setObjectName(u"verticalLayout_4")
        self.verticalLayout_4.setContentsMargins(0, 0, 0, 9)

        self.verticalLayout.addWidget(self.title_bar_frame)

        self.content_frame = QFrame(self.app_frame)
        self.content_frame.setObjectName(u"content_frame")
        sizePolicy1 = QSizePolicy(QSizePolicy.MinimumExpanding, QSizePolicy.MinimumExpanding)
        sizePolicy1.setHorizontalStretch(0)
        sizePolicy1.setVerticalStretch(0)
        sizePolicy1.setHeightForWidth(self.content_frame.sizePolicy().hasHeightForWidth())
        self.content_frame.setSizePolicy(sizePolicy1)
        self.content_frame.setStyleSheet(u"")
        self.content_frame.setFrameShape(QFrame.NoFrame)
        self.content_frame.setFrameShadow(QFrame.Plain)
        self.content_frame.setLineWidth(8)
        self.content_frame.setMidLineWidth(14)
        self.horizontalLayout_3 = QHBoxLayout(self.content_frame)
        self.horizontalLayout_3.setSpacing(6)
        self.horizontalLayout_3.setObjectName(u"horizontalLayout_3")
        self.horizontalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.page_stacked = QStackedWidget(self.content_frame)
        self.page_stacked.setObjectName(u"page_stacked")
        sizePolicy.setHeightForWidth(self.page_stacked.sizePolicy().hasHeightForWidth())
        self.page_stacked.setSizePolicy(sizePolicy)
        self.page_stacked.setMaximumSize(QSize(16777215, 16777215))
        self.page_stacked.setFrameShape(QFrame.StyledPanel)
        self.page_stacked.setFrameShadow(QFrame.Raised)
        self.page = QWidget()
        self.page.setObjectName(u"page")
        self.page_stacked.addWidget(self.page)

        self.horizontalLayout_3.addWidget(self.page_stacked)

        self.setting_frame = QFrame(self.content_frame)
        self.setting_frame.setObjectName(u"setting_frame")
        self.setting_frame.setMinimumSize(QSize(0, 0))
        self.setting_frame.setMaximumSize(QSize(0, 16777215))
        self.setting_frame.setBaseSize(QSize(0, 0))
        self.setting_frame.setFrameShape(QFrame.StyledPanel)
        self.setting_frame.setFrameShadow(QFrame.Raised)
        self.verticalLayout_7 = QVBoxLayout(self.setting_frame)
        self.verticalLayout_7.setObjectName(u"verticalLayout_7")
        self.verticalLayout_7.setContentsMargins(2, 2, 2, 2)
        self.setting_container = QFrame(self.setting_frame)
        self.setting_container.setObjectName(u"setting_container")
        self.setting_container.setMinimumSize(QSize(240, 0))
        self.setting_container.setMaximumSize(QSize(16777215, 16777215))
        self.setting_container.setStyleSheet(u"")
        self.setting_container.setFrameShape(QFrame.StyledPanel)
        self.setting_container.setFrameShadow(QFrame.Raised)
        self.verticalLayout_6 = QVBoxLayout(self.setting_container)
        self.verticalLayout_6.setObjectName(u"verticalLayout_6")
        self.verticalLayout_6.setContentsMargins(9, 9, 9, 9)

        self.verticalLayout_7.addWidget(self.setting_container)


        self.horizontalLayout_3.addWidget(self.setting_frame)


        self.verticalLayout.addWidget(self.content_frame)

        self.status_bar_frame = QFrame(self.app_frame)
        self.status_bar_frame.setObjectName(u"status_bar_frame")
        self.status_bar_frame.setMinimumSize(QSize(40, 26))
        self.status_bar_frame.setStyleSheet(u"")
        self.status_bar_frame.setFrameShape(QFrame.StyledPanel)
        self.status_bar_frame.setFrameShadow(QFrame.Raised)
        self.status_bar_frame.setLineWidth(0)
        self.verticalLayout_5 = QVBoxLayout(self.status_bar_frame)
        self.verticalLayout_5.setObjectName(u"verticalLayout_5")
        self.verticalLayout_5.setContentsMargins(0, 9, 0, 0)

        self.verticalLayout.addWidget(self.status_bar_frame)


        self.horizontalLayout.addWidget(self.app_frame)


        self.gridLayout.addWidget(self.container, 0, 0, 1, 1)

        MainWindow.setCentralWidget(self.centralwidget)

        self.retranslateUi(MainWindow)

        QMetaObject.connectSlotsByName(MainWindow)
    # setupUi

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle("")
    # retranslateUi




#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    :   temp_monitor.py
@Time    :   2022/05/10 12:16:47
@Author  :   Calros Teng 
@Version :   1.0
@Contact :   303359166@qq.com
@License :   (C)Copyright 2017-2018, Xin Yuan Studio
@Desc    :   emm...
温度采集

"""

# here put the import lib
from ppadb.device import Device
from .base.chart import MonitorChart
from perfcat.modules.profiler.temp import MarkTempSampler
from PySide6.QtCharts import QLineSeries

class TempMonitor(MonitorChart):
    def __init__(
        self,
        parent=None,
    ):
        super().__init__(
            y_axis_name="℃",
            parent=parent,
        )
        self.setObjectName("Temperature")
        self.setToolTip("不少设备无法获得温度，会显示为-1")
        self.mark_temp_sampler = None

        self._sample_data = {}

        self.create_series("整体温度", QLineSeries(self), lambda v: f"{v}℃")
        self.create_series("CPU温度", QLineSeries(self), lambda v: f"{v}℃")
        self.create_series("GPU温度", QLineSeries(self), lambda v: f"{v}℃")
        self.create_series("NPU温度", QLineSeries(self), lambda v: f"{v}℃")
        self.create_series("电池温度", QLineSeries(self), lambda v: f"{v}℃")

    def sample(self, sec: int, device: Device, package_name: str):

        if self.mark_temp_sampler is None:
            self.mark_temp_sampler = MarkTempSampler(device)

        temp_data = self.mark_temp_sampler.get_temp()

        self._sample_data[sec] = {
            "整体温度": temp_data["total"],
            "CPU温度":temp_data["cpu"],
            "GPU温度": temp_data["gpu"],
            "NPU温度": temp_data["npu"],
            "电池温度": temp_data["battery"]
        }

        for k,v in self._sample_data[sec].items():
            self.add_point(k, sec, v)

    def reset_series_data(self):
        self.mark_temp_sampler = None
        self._sample_data = {}
        return super().reset_series_data()

    def to_dict(self, all: bool = True) -> dict:
        if all:
            return self._sample_data
        else:
            start = self.record_range[0]
            end = self.record_range[1]

            data = {}
            for k,v in self._sample_data.items():
                if start <= k <= end:
                    data[k] = v
            return data

    def from_dict(self, data: dict):
        for sec, data_table in data.items():
            for k, v in data_table.items():
                self.add_point(k,int(sec), v)
            self.flush()



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    :   cpu.py
@Time    :   2022/05/10 10:33:37
@Author  :   Calros Teng 
@Version :   1.0
@Contact :   303359166@qq.com
@License :   (C)Copyright 2017-2018, Xin Yuan Studio
@Desc    :   emm...
参考：
    [1] https://blog.gamebench.net/measuring-cpu-usage-in-mobile-devices
    [2] https://github.com/alipay/SoloPi/blob/master/src/shared/src/main/cpp/cpu_usage.c
"""

# here put the import lib

import re
from ppadb.device import Device
from ppadb.plugins.device.cpustat import TotalCPUStat
from typing import Dict


def get_all_cpu_freq(dev: Device, filename) -> list:
    count = dev.cpu_count()
    values = {}

    for index in range(count):
        CMD_ROOT = f"cat /sys/devices/system/cpu/cpu{index}/cpufreq"
        value = dev.shell(f"{CMD_ROOT}/{filename}")
        values[index] = int(value) / 1024

    return values


def get_all_cpu_max_freq(dev: Device) -> list:
    return get_all_cpu_freq(dev, "cpuinfo_max_freq")


def get_all_cpu_cur_freq(dev: Device) -> list:
    return get_all_cpu_freq(dev, "scaling_cur_freq")


def normalize_factor(device: Device):
    # 合计所有CPU最大频率
    max_freq = get_all_cpu_max_freq(device)
    total_max_freq = sum(max_freq.values())

    # 找出所有在在线的CPU
    online_cmd = "cat /sys/devices/system/cpu/online"
    online = device.shell(online_cmd)
    phases = [
        list(map(lambda v: int(v), sub))
        for sub in [p.split("-") for p in online.split(",")]
    ]

    # 合计所有在线CPU的当前频率
    cur_freq_sum = 0
    all_cur_freq = get_all_cpu_cur_freq(device)
    for p in phases:
        for i in range(p[0], p[1] + 1):
            cur_freq_sum += all_cur_freq[i]

    return cur_freq_sum / total_max_freq


def get_all_cpu_state(device: Device) -> Dict[int, TotalCPUStat]:
    pattern = re.compile(
        "cpu(\d)\s+([\d]+)\s([\d]+)\s([\d]+)\s([\d]+)\s([\d]+)\s([\d]+)\s([\d]+)\s([\d]+)\s([\d]+)\s([\d]+)\s"
    )
    cpu_state_info = device.shell("cat /proc/stat")
    matches = pattern.findall(cpu_state_info)

    all_cpu_state = {
        int(group[0]): TotalCPUStat(*map(lambda x: int(x), group[1:]))
        for group in matches
    }

    return all_cpu_state



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    :   logcat_provider.py
@Time    :   2022/05/27 12:48:25
@Author  :   Calros Teng 
@Version :   1.0
@Contact :   303359166@qq.com
@License :   (C)Copyright 2017-2018, Xin Yuan Studio
@Desc    :   emm...
"""

# here put the import lib
import re
import subprocess
import pkg_resources
import logging
import time
from typing import Optional
from shutil import which
from PySide6.QtCore import QThread, QObject, SignalInstance, Signal

log = logging.getLogger(__name__)


class LogProvider(QThread):
    """
    Logcat数据提供者，只负责抓log数据然后解析成行然后发信号出去
    """

    new_log_added: SignalInstance = Signal(list)

    MAX_BUFFER_SIZE = 10000
    TIMEOUT = 1

    def __init__(self, parent: Optional[QObject] = None) -> None:
        super().__init__(parent)

        self.process = None
        self.serial = None
        self.buffer = []
        self.last_flush_time = time.time()

    @property
    def adb_path(self):
        path = which("adb")
        default_adb_path = pkg_resources.resource_filename("perfcat", "adb/adb.exe")
        return path or default_adb_path

    def run(self) -> None:
        subprocess.call([self.adb_path, "-s", self.serial, "logcat", "-c"], shell=True)
        self.process = subprocess.Popen(
            [self.adb_path, "-s", self.serial, "logcat"],
            shell=True,
            text=True,
            stdout=subprocess.PIPE,
            stderr=subprocess.PIPE,
            encoding="utf-8",
        )

        while self.process.poll() is None:
            try:
                line = self.process.stdout.readline()
                parsed_line = self._parse(line)
                if parsed_line:
                    if len(self.buffer) >= self.MAX_BUFFER_SIZE or self.is_timeout:
                        self.flush()
                    else:
                        self.buffer.append(parsed_line)
            finally:
                continue

        log.debug("停止日志采集")

    def start(
        self, serial: str, priority: QThread.Priority = QThread.Priority.NormalPriority
    ) -> None:
        self.serial = serial
        return super().start(priority)

    def exit(self, retcode: int = 0) -> None:
        if self.process:
            self.process.kill()
        return super().exit(retcode)

    def flush(self):
        if self.buffer:
            self.new_log_added.emit(self.buffer)
            self.buffer.clear()
        self.last_flush_time = time.time()

    @property
    def is_timeout(self):
        return (time.time() - self.last_flush_time) > self.TIMEOUT

    def _parse(self, msg: str):
        try:
            r = re.search("(.*[0-9\s][VISFEWD]\s.*?):\s(.*)", msg)
            try:
                _data_list = r.group(1).split(" ")
            except Exception:
                return ["", "", "", "", "", "", msg]
            while "" in _data_list:
                _data_list.remove("")
            _content = r.group(2)
            _date = _data_list[0]
            _time = _data_list[1]
            _pid = _data_list[2]
            _tid = _data_list[3]
            _priority = _data_list[4]
            try:
                _tag = _data_list[5]
            except Exception:
                _tag = ""
            return [_date, _time, _pid, _tid, _priority, _tag, _content]
        except Exception as e:
            log.exception(msg)
            return None



import logging
from typing import List
from ppadb.client import Client
from ppadb.device import Device

log = logging.getLogger(__name__)


class DefaultCpuTempSampler:
    TEMP_FILE_PATHS = [
        "/sys/devices/system/cpu/cpu0/cpufreq/cpu_temp",
        "/sys/devices/system/cpu/cpu0/cpufreq/FakeShmoo_cpu_temp",
        "/sys/class/thermal/thermal_zone0/temp",
        "/sys/class/i2c-adapter/i2c-4/4-004c/temperature",
        "/sys/devices/platform/tegra-i2c.3/i2c-4/4-004c/temperature",
        "/sys/devices/platform/omap/omap_temp_sensor.0/temperature",
        "/sys/devices/platform/tegra_tmon/temp1_input",
        "/sys/kernel/debug/tegra_thermal/temp_tj",
        "/sys/devices/platform/s5p-tmu/temperature",
        "/sys/class/thermal/thermal_zone1/temp",
        "/sys/class/hwmon/hwmon0/device/temp1_input",
        "/sys/devices/virtual/thermal/thermal_zone1/temp",
        "/sys/devices/virtual/thermal/thermal_zone0/temp",
        "/sys/class/thermal/thermal_zone3/temp",
        "/sys/class/thermal/thermal_zone4/temp",
        "/sys/class/hwmon/hwmonX/temp1_input",
        "/sys/devices/platform/s5p-tmu/curr_temp",
    ]

    def __init__(self, device: Device) -> None:
        self.device = device
        self.cpu_temp_valid_path = None

    def cpu_temp(self):
        if not self.cpu_temp_valid_path:
            for path in self.TEMP_FILE_PATHS:
                temp = self.__try_get_temp(path)
                if temp is None:
                    continue
                else:
                    return temp
        else:
            return self.__try_get_temp(self.cpu_temp_valid_path)

    def __try_get_temp(self, path):
        try:
            print(f"读取 {path}")
            result = self.device.shell(f"cat {path}")
            temp = float(result)
            print(f"{temp} valid {self.is_temp_valid(temp)}")
            print(f"{temp/1000} valid {self.is_temp_valid(temp/1000)}")
            if self.is_temp_valid(temp):
                self.cpu_temp_valid_path = path
                return temp
            elif self.is_temp_valid(temp / 1000):
                self.cpu_temp_valid_path = path
                return temp / 1000
        except Exception as e:
            print(e)
            return None

    def is_temp_valid(self, value):
        return -30 <= value <= 250


class MarkTempSampler:
    CPU_MARKS = [
        "mtktscpu",  # 联发科
        "tsens_tz_sensor",  # 高通
        "exynos",  # 三星
        "sdm-therm",  # 高通晓龙
        "cpu-0-0-us",  # 通用
        "soc_thermal",  # 通用
        "cpu",  # 通用
    ]
    BATTERY_MARKS = ["battery", "Battery"]
    NPU_MARKS = ["npu-usr", "npu"]
    GPU_MARKS = ["gpuss-0-us", "gpu"]

    SENSOR_LIST_CMD = "cat /sys/devices/virtual/thermal/thermal_zone*/type"
    SENSOR_FILE_LIST_CMD = "cd /sys/devices/virtual/thermal/ && ls|grep thermal_zone"
    SENSOR_TEMP_LIST_CMD = "cat /sys/devices/virtual/thermal/thermal_zone*/temp"
    TEMP_CMD = "cat /sys/devices/virtual/thermal/{filename}/temp"

    def __init__(self, device: Device) -> None:
        self.device = device
        self._sensor_list = self.get_sensor_list()
        self._sensor_filename_list = self.get_sensor_filename_list()
        self.prop = self.device.get_properties()

    def get_sensor_list(self):
        list_str: str = self.device.shell(self.SENSOR_LIST_CMD)
        return list_str.split("\n")

    def get_sensor_filename_list(self):
        list_str: str = self.device.shell(self.SENSOR_FILE_LIST_CMD)
        return list_str.split("\n")

    def get_sensor_temp(self, index: int):
        file_name = self._sensor_filename_list[index]
        temp_value = self.device.shell(self.TEMP_CMD.format(filename=file_name)) or "0"
        temp_value = self.str_to_temp(temp_value)

        return temp_value

    def get_senser_index(self, marks):
        sensor_list: List[str] = self._sensor_list
        for mark in marks:
            for index, sensor_name in enumerate(sensor_list):
                if sensor_name.lower().startswith(mark):
                    return index

        manufacturer = self.prop["ro.product.manufacturer"]  # 制造商
        model = self.prop["ro.product.model"]  # 型号
        log.warning(f"{manufacturer}-{model} 没有匹配到{marks} 无法获得其温度，改用整体温度表示")
        return 0

    def is_temp_valid(self, value):
        return -30 <= value <= 250

    def get_temp(self):
        total_temp_index = 0
        cpu_temp_index = self.get_senser_index(self.CPU_MARKS)
        gpu_temp_index = self.get_senser_index(self.GPU_MARKS)
        npu_temp_index = self.get_senser_index(self.NPU_MARKS)
        battery_temp_index = self.get_senser_index(self.BATTERY_MARKS)

        total_temp = (
            self.get_sensor_temp(total_temp_index)
            if total_temp_index is not None
            else 0
        )
        cpu_temp = (
            self.get_sensor_temp(cpu_temp_index) if cpu_temp_index is not None else 0
        )
        gpu_temp = (
            self.get_sensor_temp(gpu_temp_index) if gpu_temp_index is not None else 0
        )
        npu_temp = (
            self.get_sensor_temp(npu_temp_index) if npu_temp_index is not None else 0
        )
        battery_temp = (
            self.get_sensor_temp(battery_temp_index)
            if battery_temp_index is not None
            else 0
        )

        return {
            "total": total_temp,
            "cpu": cpu_temp,
            "gpu": gpu_temp,
            "npu": npu_temp,
            "battery": battery_temp,
        }

    def str_to_temp(self, txt: str):
        try:
            temp = float(txt)
            if self.is_temp_valid(temp):
                return temp
            elif self.is_temp_valid(temp / 10):
                return temp / 10
            elif self.is_temp_valid(temp / 1000):
                return temp / 1000
            return 0
        except Exception:
            return -1


if __name__ == "__main__":
    from ppadb.client import Client

    adb = Client()
    dev = adb.devices()[0]

    util = MarkTempSampler(dev)
    print(util.get_senser_index(util.CPU_MARKS))
    print("all", util.get_temp())



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    :   win_title_bar.py
@Time    :   2022/04/27 18:55:33
@Author  :   Calros Teng 
@Version :   1.0
@Contact :   303359166@qq.com
@License :   (C)Copyright 2017-2018, Xin Yuan Studio
@Desc    :   windows系统下的标题栏，用到win32 api去实现窗体移动
"""

# here put the import lib

import win32api
import win32gui
import win32con

from PySide6.QtWidgets import QMainWindow
from PySide6.QtCore import Qt
from PySide6.QtGui import QMouseEvent, QCursor
from .base_title_bar import BaseTitleBar


class WinTitleBar(BaseTitleBar):
    def __init__(self, parent: QMainWindow) -> None:
        super().__init__(parent)

    def mousePressEvent(self, event: QMouseEvent) -> None:

        if self.rect().contains(event.pos()):
            win32gui.ReleaseCapture()
            win32api.SendMessage(
                self.window().winId(),
                win32con.WM_SYSCOMMAND,
                win32con.SC_MOVE | win32con.HTCAPTION,
                0,
            )
            event.ignore()
        return super().mousePressEvent(event)



import PySide6
import logging

from typing import Optional
from PySide6.QtWidgets import QWidget, QGraphicsOpacityEffect
from PySide6.QtCore import (
    QPropertyAnimation,
    QEasingCurve,
    QTimer,
    QParallelAnimationGroup,
    Qt,
)

import perfcat

from .ui_notification import Ui_Notification
from perfcat.ui.constant import ButtonStyle, Color

log = logging.getLogger(__name__)


class Notification(QWidget, Ui_Notification):

    count = 1

    def __init__(
        self,
        parent: Optional[QWidget] = None,
        msg: str = "消息提示",
        style: ButtonStyle = ButtonStyle.warning,
    ) -> None:
        parent = parent.window()
        super().__init__(parent)
        self.setupUi(self)

        self.setStyleSheet("")

        self.move(
            parent.rect().right() - self.width(),
            parent.rect().bottom() - self.height() * Notification.count,
        )

        Notification.count += 1

        self.setCursor(Qt.CursorShape.PointingHandCursor)

        self.btn_msg.setText(msg)
        self.btn_msg.setStyleSheet(f"background-color:{Color[style.value]};")

        width_animation = QPropertyAnimation(self.frame, b"maximumWidth")
        width_animation.setStartValue(0)
        width_animation.setEndValue(self.frame.maximumWidth())
        width_animation.setEasingCurve(QEasingCurve.InOutBounce)
        width_animation.setDuration(200)
        self.animation = width_animation

        self.destroyed.connect(lambda: self._on_destroyed())

    def showEvent(self, event: PySide6.QtGui.QShowEvent) -> None:

        self.animation.setDirection(QPropertyAnimation.Forward)
        self.animation.start()

        # 定时销毁
        self.auto_destory_timer = QTimer(self)
        self.auto_destory_timer.setInterval(5000)
        self.auto_destory_timer.setSingleShot(True)
        self.auto_destory_timer.timeout.connect(lambda: self.destroy())
        self.auto_destory_timer.start()

        return super().showEvent(event)

    def destroy(
        self, destroyWindow: bool = True, destroySubWindows: bool = True
    ) -> None:
        self.animation.setDirection(QPropertyAnimation.Backward)
        self.animation.start()
        log.debug("开始销毁动画")
        self.animation.finished.connect(self._on_deleted)
        return super().destroy()

    def _on_destroyed(self):
        log.debug("减少Notification.count的计数")
        Notification.count -= 1

    def _on_deleted(self):
        self.deleteLater()
        log.debug("调用deletelater")



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    :   title_bar.py
@Time    :   2022/04/27 17:09:08
@Author  :   Calros Teng 
@Version :   1.0
@Contact :   303359166@qq.com
@License :   (C)Copyright 2017-2018, Xin Yuan Studio
@Desc    :
标题栏组件，本身没有包含具体逻辑，具体按钮逻辑由使用它的模块来去实现
"""

# here put the import lib
import logging

from PySide6.QtWidgets import QWidget, QMainWindow, QGraphicsDropShadowEffect
from PySide6.QtCore import Qt, QEvent
from PySide6.QtGui import QMouseEvent, QCursor, QColor
from .ui_title_bar import Ui_TitleBar

log = logging.getLogger(__name__)


class BaseTitleBar(QWidget, Ui_TitleBar):
    def __init__(self, parent: QMainWindow) -> None:
        super().__init__(parent)
        self.setupUi(self)
        # 清空qt designer写死的qss
        self.setStyleSheet("")
        # 清空qt designer设计时的文本
        self.lb_title.setText("")

        self.window().windowTitleChanged.connect(self._handle_window_title)

        self._setup_control_buttons()

    def _handle_window_title(self, title: str):
        file_path = self.window().windowFilePath()
        modified = self.window().isWindowModified()
        title_str = f"{file_path}{'*' if modified else ''}"
        self.lb_title.setText(title_str)

    def mouseDoubleClickEvent(self, event: QMouseEvent) -> None:
        if self.window().isMaximized():
            self.window().showNormal()
        else:
            self.window().showMaximized()
        return super().mouseDoubleClickEvent(event)

    def _setup_control_buttons(self):
        main_win: QMainWindow = self.window()

        self.btn_min.clicked.connect(self.parent().showMinimized)
        self.btn_close.clicked.connect(self.parent().close)

        # MonkeyPath掉主窗口的最大最小化方法，这样被系统最大最小化时候
        # 最大最小化按钮的状态也会正确
        def showNormal():
            log.debug("窗口最大化恢复")
            self.btn_max.setChecked(False)
            super(QMainWindow, main_win).showNormal()

        def showMaximized():
            log.debug("窗口最大化")
            self.btn_max.setChecked(True)
            super(QMainWindow, main_win).showMaximized()

        def changeEvent(event:QEvent):
            if event.type() == QEvent.WindowStateChange:
                self.btn_max.blockSignals(True)
                self.btn_max.setChecked(main_win.isMaximized())
                self.btn_max.blockSignals(False)

        main_win.showNormal = showNormal
        main_win.showMaximized = showMaximized
        main_win.changeEvent = changeEvent

        self.btn_max.toggled.connect(self._toggle_maximized)
        self.window().installEventFilter(self)

    def _toggle_maximized(self, checked):
        if checked:
            self.window().showMaximized()
        else:
            self.window().showNormal()

    @property
    def title(self):
        return self.lb_title.text()

    @title.setter
    def title(self, value: str):
        self.lb_title.setText(value)



"""
@File    :   __init__.py
@Time    :   2022/04/27 16:11:12
@Author  :   Calros Teng 
@Version :   1.0
@Contact :   303359166@qq.com
@License :   (C)Copyright 2017-2018, Xin Yuan Studio
@Desc    :   主体窗口

#todo:
设备观察器基类
只产生拔插事件
"""


from typing import Optional, Union
import PySide6

from PySide6.QtCore import QCoreApplication,QObject, QAbstractNativeEventFilter,SignalInstance,Signal


class BaseHotPlugNativeEventFilter(QObject, QAbstractNativeEventFilter):
    
    device_changed: SignalInstance = Signal()
    device_added: SignalInstance = Signal()
    device_removed: SignalInstance = Signal()

    def __init__(self, parent: Optional[PySide6.QtCore.QObject] = None) -> None:
        super().__init__(parent)    
        super(QObject, self).__init__()
        
    def install(self, app:QCoreApplication):
        self.setParent(app)
        app.installNativeEventFilter(self)
        
    def uninstall(self, app:QCoreApplication):
        self.setParent(None)
        app.removeNativeEventFilter(self)


from PySide6.QtWidgets import QWidget, QPushButton
from perfcat.ui.page import Page
from .ui_home import Ui_Home


class Home(Page, Ui_Home):
    def __init__(self, parent) -> None:
        super().__init__(parent)

        self.setupUi(self)



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    :   effects.py
@Time    :   2022/04/27 20:09:48
@Author  :   Calros Teng 
@Version :   1.0
@Contact :   303359166@qq.com
@License :   (C)Copyright 2017-2018, Xin Yuan Studio
@Desc    :   通用特效封装到这里用工厂的方式获得
"""

# here put the import lib
from typing import Union
from PySide6.QtWidgets import QWidget, QGraphicsDropShadowEffect, QLayout
from PySide6.QtGui import QColor
from PySide6.QtCore import QPropertyAnimation, QEasingCurve

# 动画缓存
# 因为动画对象在播放的过程中如果不引用着还是会被销毁
anim_temp = []


def set_shadow_effect(owner: QWidget):
    shadow_effect = QGraphicsDropShadowEffect(owner)
    shadow_effect.setOffset(1, 1)
    shadow_effect.setColor(QColor("#1b1e23"))
    shadow_effect.setBlurRadius(5)
    owner.setGraphicsEffect(shadow_effect)


def set_h_expand_anim(
    owner: QWidget, checked: bool, max: float, min: float
) -> QPropertyAnimation:
    anim = QPropertyAnimation(owner, b"maximumWidth")
    anim_temp.append(anim)
    anim.setStartValue(owner.maximumWidth())
    if checked:
        anim.setEndValue(max)
    else:
        anim.setEndValue(min)

    anim.setEasingCurve(QEasingCurve.InOutCubic)
    anim.setDuration(500)
    anim.start()

    def delete():
        anim_temp.remove(anim)

    # 播放完自己移除掉anim对象的引用，让其自生自灭
    anim.finished.connect(delete)
    return anim


def clear_layout(layout:Union[QLayout,QWidget]):
    """
    清空layout里的widget

    _extended_summary_

    Args:
        layout (QLayout): _description_
    """
    if isinstance(layout, QWidget):
        layout = layout.layout()

    counts = layout.count()
    for index in range(counts):
        item = layout.itemAt(index)
        layout.removeItem(item)



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    :   __main__.py
@Time    :   2022/04/28 06:13:15
@Author  :   Calros Teng 
@Version :   1.0
@Contact :   303359166@qq.com
@License :   (C)Copyright 2017-2018, Xin Yuan Studio
@Desc    :   主启动文件
"""

# # here put the import lib
# # 设置环境变量切换成生产模式
import os
import sys

os.environ["MODE"] = "production"  # noqa
from perfcat.app import PerfcatApplication  # noqa
from perfcat import asset_rc  # noqa


def main():
    app = PerfcatApplication(sys.argv)
    return app.exec()


if __name__ == "__main__":
    sys.exit(main())



# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'logcat.ui'
##
## Created by: Qt User Interface Compiler version 6.4.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QDate, QDateTime, QLocale,
    QMetaObject, QObject, QPoint, QRect,
    QSize, QTime, QUrl, Qt)
from PySide6.QtGui import (QAction, QBrush, QColor, QConicalGradient,
    QCursor, QFont, QFontDatabase, QGradient,
    QIcon, QImage, QKeySequence, QLinearGradient,
    QPainter, QPalette, QPixmap, QRadialGradient,
    QTransform)
from PySide6.QtWidgets import (QAbstractItemView, QApplication, QComboBox, QFrame,
    QHBoxLayout, QHeaderView, QLabel, QLineEdit,
    QPushButton, QSizePolicy, QTableView, QVBoxLayout,
    QWidget)
import asset_rc

class Ui_Logcat(object):
    def setupUi(self, Logcat):
        if not Logcat.objectName():
            Logcat.setObjectName(u"Logcat")
        Logcat.resize(688, 200)
        Logcat.setMaximumSize(QSize(16777215, 16777215))
        Logcat.setStyleSheet(u"*{\n"
"    border-radius:8;\n"
"    color:#6c7c96;\n"
"}\n"
"\n"
"#container {\n"
"background-color:#2c313c;\n"
"}\n"
"\n"
"#left_menu_frame{\n"
"background-color:#1b1e23;\n"
"}\n"
"\n"
"#title_bar_frame{\n"
"background-color:#343b48;\n"
"}\n"
"\n"
"#status_bar_frame{\n"
"background-color:#343b48;\n"
"}\n"
"\n"
"#content_frame{\n"
"background-color:#343b48;\n"
"}\n"
"\n"
"#setting_frame {\n"
"background-color:#3c4454;\n"
"}\n"
"\n"
"#left_column_frame {\n"
"background-color:#343b48;\n"
"}\n"
"\n"
"/* \u4fa7\u8fb9\u83dc\u5355\u680f\u6837\u5f0f */\n"
"\n"
"#LeftMenu {\n"
"background-color: #005dfd;\n"
"}\n"
"\n"
"#LeftMenu QPushButton {\n"
"background-color:#1b1e23;\n"
"height:40;\n"
"text-align:left;\n"
"padding-left:15;\n"
"padding-top:2;\n"
"padding-bottom:2;\n"
"color:#6b7884;\n"
"}\n"
"\n"
"#LeftMenu QPushButton:hover{\n"
"background-color:#21252d;\n"
"}\n"
"\n"
"#LeftMenu QPushButton:pressed{\n"
"background-color:#2c313c;\n"
"}\n"
"\n"
"#LeftMenu QPushButton:checked{\n"
"background-color:#2c313c;\n"
"}\n"
""
                        "\n"
"#LeftMenu QPushButton:focus{\n"
"border:none;\n"
"}\n"
"\n"
"\n"
"#LeftMenu #bottom{\n"
"border-top:1 solid #272c36;\n"
"border-radius: 0;\n"
"}\n"
"\n"
"#LeftMenu #nav_menu {\n"
"border-top:1 solid #272c36;\n"
"border-radius: 0\uff1b\n"
"}\n"
"\n"
"#LeftMenu #scrollArea,#scrollAreaWidgetContents_3{\n"
"background-color:#1b1e23;\n"
"border:none;\n"
"}\n"
"\n"
"#LeftMenu #btn_toggle:checked{\n"
"background-color:#21252d;\n"
"}\n"
"\n"
"\n"
"/* \u6807\u9898\u680f\u6837\u5f0f */\n"
"\n"
"#TitleBar #bg{\n"
"background-color:#343b48;\n"
"border-radius:8;\n"
"}\n"
"\n"
"#TitleBar #logo {\n"
"border: 1px solid #3c4454;\n"
"padding-right:10px;\n"
"border-top:none;\n"
"border-bottom:none;\n"
"border-left:none;\n"
"margin-right:5px;\n"
"border-radius:0;\n"
"}\n"
"\n"
"#TitleBar  #logo_title{\n"
"color:#77b3f1;\n"
"font-size:20px;\n"
"font-weight:bold;\n"
"}\n"
"\n"
"#TitleBar  #lb_title{\n"
"font-size:14px;\n"
"color:#6c7c96;\n"
"}\n"
"\n"
"#TitleBar  QToolButton{\n"
"background-color:#343b48;\n"
"border:none;\n"
""
                        "border-radius:4;\n"
"padding: 4;\n"
"}\n"
"\n"
"#TitleBar QToolButton:hover,\n"
"#TitleBar QToolButton:checked{\n"
"background-color:#3c4454;\n"
"}\n"
"\n"
"\n"
"#TitleBar QToolButton:pressed{\n"
"background-color:#e2e9f7;\n"
"}\n"
"\n"
"#TitleBar #tool{\n"
"border:1px solid #3c4454;\n"
"border-top:none;\n"
"border-bottom:none;\n"
"margin-right:5px;\n"
"border-radius:0;\n"
"}\n"
"\n"
"\n"
"#LeftColumn{\n"
"background-color:#343b48;\n"
"}\n"
"\n"
"#LeftColumn #top{\n"
"background-color: #3c4454;\n"
"}\n"
"\n"
"#leftColumn #icon{\n"
"\n"
"}\n"
"\n"
"#LeftColumn #title{\n"
"color:#6c7c96;\n"
"}\n"
"\n"
"#LeftColumn QToolButton{\n"
"border:none;\n"
"padding:4;\n"
"background-color: #3c4454;\n"
"}\n"
"\n"
"#LeftColumn #btn_close:hover{\n"
"background-color:#343b48;\n"
"}\n"
"\n"
"#LeftColumn #btn_close:pressed{\n"
"background-color:#1b1e23;\n"
"}\n"
"\n"
"\n"
"/* \u901a\u7528\u63a7\u4ef6 */\n"
"\n"
"QToolTip { \n"
"color:#6b7884;\n"
"background-color: #1b1e23; \n"
"border-left: 2px solid #4f9fee;\n"
"border-radius:"
                        " 8px;\n"
"}\n"
"\n"
"QGroupBox{\n"
"	border: 2px solid gray; \n"
"    border-radius: 3px; \n"
"    margin:10;\n"
"}\n"
"\n"
"QGroupBox::title { \n"
"    subcontrol-position: center top; /* position at the top left*/ \n"
"	subcontrol-origin: border;\n"
"	margin-top:-20px;\n"
"\n"
"}\n"
"\n"
"/* Button */\n"
"QAbstractButton{\n"
"background-color:#1b1e23;\n"
"border:none;\n"
"border-radius:4;\n"
"padding: 4;\n"
"outline:none;\n"
"width:36;\n"
"height:36;\n"
"}\n"
"\n"
"QAbstractButton:hover,\n"
"QAbstractButton:checked{\n"
"background-color:#21252d;\n"
"}\n"
"\n"
"\n"
"QAbstractButton:pressed{\n"
"background-color:#272c36;\n"
"}\n"
"\n"
"QAbstractButton:disabled{\n"
"background-color: #272c36;\n"
"}\n"
"\n"
"QAbstractButton:checked{\n"
"background-color:#568af2;\n"
"color:black;\n"
"}\n"
"\n"
"QAbstractButton:focus{\n"
"border: 2px solid #568af2;\n"
"}\n"
"\n"
"QAbstractButton[style~='success']:checked{\n"
"    background-color: #67c23a;\n"
"}\n"
"QAbstractButton[style~='warning']:checked{\n"
"    background-col"
                        "or: #e6a23c;\n"
"}\n"
"QAbstractButton[style~='danger']:checked{\n"
"    background-color: #f56c6c;\n"
"}\n"
"QAbstractButton[style~='info']:checked{\n"
"    background-color: #909399;\n"
"}\n"
"\n"
"/* CheckBox */\n"
"\n"
"QCheckBox::indicator{\n"
"    border:2px solid #6c7c96;\n"
"    border-radius: 2px;\n"
"    width:10px;\n"
"    height:10px;\n"
"    margin-left:8px;\n"
"}\n"
"\n"
"QCheckBox::indicator:checked{\n"
"    border:2px solid black;\n"
"    image: url(:/icon/assets/svg/checkmark.svg);\n"
"}\n"
"\n"
"QRadioButton::indicator{\n"
"    border:1px solid #6c7c96;\n"
"    background-color:#6c7c96;\n"
"    border-radius: 4px;\n"
"    width:10px;\n"
"    height:10px;\n"
"    margin-left:8px;\n"
"}\n"
"\n"
"QRadioButton::indicator:checked{\n"
"    border:1px solid #fff;\n"
"    background-color:black;\n"
"}\n"
"\n"
"/* TextEdit */\n"
"QPlainTextEdit,\n"
"QTextEdit,\n"
"QLineEdit{\n"
"    background-color: #1b1e23;\n"
"    padding:8px;\n"
"}\n"
"\n"
"QPlainTextEdit:focus,\n"
"QTextEdit:focus,\n"
"QLineEdit:"
                        "focus{\n"
"    border: 2px solid #568af2;\n"
"}\n"
"\n"
"QPlainTextEdit:read-only,\n"
"QTextEdit:read-only,\n"
"QLineEdit:read-only{\n"
"    border:none;\n"
"}\n"
"\n"
"/* ProgressBar */\n"
"QProgressBar{\n"
"    background-color: #1b1e23;\n"
"    text-align:center;\n"
"    font-weight: bold;\n"
"}\n"
"\n"
"QProgressBar::chunk:horizontal{\n"
"    background-color: #4f9fee;\n"
"    border-radius: 8px;\n"
"    border-top-right-radius: 0;\n"
"    border-bottom-right-radius:0;\n"
"}\n"
"QProgressBar::chunk:vertical{\n"
"    background-color: #4f9fee;\n"
"    border-radius: 8px;\n"
"    border-top-left-radius: 0;\n"
"    border-top-right-radius:0;\n"
"}\n"
"\n"
"\n"
"/* ScrollBar */\n"
"QScrollBar:horizontal{\n"
"    background-color: #2c313c;\n"
"    border-radius: 0;\n"
"    border:none;\n"
"    max-height: 8px;\n"
"}\n"
"\n"
"QScrollBar::handle:horizontal{\n"
"    background-color:#568af2;\n"
"    border-radius:4px;\n"
"    min-width: 25px;\n"
"}\n"
"\n"
"QScrollBar::add-page:horizontal{\n"
"    background-color"
                        ":none;\n"
"}\n"
"QScrollBar::sub-page:horizontal{\n"
"    background-color:none;\n"
"}\n"
"\n"
"QScrollBar::add-line:horizontal{\n"
"    background-color:#272c36;\n"
"    border:none;\n"
"    width:0px;\n"
"    border-top-right-radius: 4px;\n"
"    border-bottom-right-radius: 4px;\n"
"    /* subcontrol-position:right; */\n"
"    subcontrol-origin:margin;\n"
"}\n"
"QScrollBar::sub-line:horizontal{\n"
"    background-color:#272c36;\n"
"    border:none;\n"
"    width:0px;\n"
"    border-top-right-radius: 4px;\n"
"    border-bottom-right-radius: 4px;\n"
"    /* subcontrol-position:right; */\n"
"    subcontrol-origin:margin;\n"
"}\n"
"\n"
"/* Vertical */\n"
"QScrollBar:vertical{\n"
"    background-color: #2c313c;\n"
"    border-radius: 0;\n"
"    border:none;\n"
"    max-width: 8px;\n"
"}\n"
"\n"
"QScrollBar::handle:vertical{\n"
"    background-color:#568af2;\n"
"    border-radius:4px;\n"
"    min-height: 25px;\n"
"}\n"
"\n"
"QScrollBar::add-page:vertical{\n"
"    background-color:none;\n"
"}\n"
"QScrollBar::sub-pa"
                        "ge:vertical{\n"
"    background-color:none;\n"
"}\n"
"\n"
"QScrollBar::add-line:vertical{\n"
"    background-color:#272c36;\n"
"    border:none;\n"
"    width:0px;\n"
"    border-top-right-radius: 4px;\n"
"    border-top-left-radius: 4px;\n"
"    /* subcontrol-position:right; */\n"
"    subcontrol-origin:margin;\n"
"}\n"
"QScrollBar::sub-line:vertical{\n"
"    background-color:#272c36;\n"
"    border:none;\n"
"    width:0px;\n"
"    border-top-right-radius: 4px;\n"
"    border-top-left-radius: 4px;\n"
"    /* subcontrol-position:right; */\n"
"    subcontrol-origin:margin;\n"
"}\n"
"\n"
"\n"
"/* Slider */\n"
"\n"
"QSlider:horizontal{\n"
"    margin:8;\n"
"}\n"
"\n"
"QSlider::groove:horizontal{\n"
"    background-color: #1b1e23;\n"
"    border-radius: 4px;\n"
"    margin:0px;\n"
"    height: 10px;\n"
"}\n"
"QSlider::groove:horizontal:hover{\n"
"    background-color: #21252d;\n"
"}\n"
"\n"
"QSlider::handle:horizontal{\n"
"    border:none;\n"
"    height:16px;\n"
"    width:16px;\n"
"    margin: -3px;\n"
"    bord"
                        "er-radius: 8px;\n"
"    background-color: #4f9fee;\n"
"}\n"
"\n"
"QSlider:vertical{\n"
"    margin:8;\n"
"}\n"
"\n"
"QSlider::groove:vertical{\n"
"    background-color: #1b1e23;\n"
"    border-radius: 4px;\n"
"    margin:0px;\n"
"    width: 10px;\n"
"}\n"
"QSlider::groove:vertical:hover{\n"
"    background-color: #21252d;\n"
"}\n"
"\n"
"QSlider::handle:vertical{\n"
"    border:none;\n"
"    height:16px;\n"
"    width:16px;\n"
"    margin: -3px;\n"
"    border-radius: 8px;\n"
"    background-color: #4f9fee;\n"
"}\n"
"\n"
"\n"
"/* ComboBox */\n"
"\n"
"QComboBox{\n"
"    background-color: #1b1e23;\n"
"    padding:8px;\n"
"    selection-background-color:transparent;\n"
"}\n"
"\n"
"QComboBox:disabled{\n"
"    background-color: #272c36;\n"
"}\n"
"\n"
"QComboBox::drop-down{\n"
"    border-top-right-radius: 8px;\n"
"    border-bottom-right-radius: 8px;\n"
"    subcontrol-origin:padding;\n"
"    subcontrol-position:center right;\n"
"    background-color:#1b1e23;\n"
"    width:10px;\n"
"    padding:10px;\n"
"}\n"
"\n"
""
                        "QComboBox::drop-down:disabled{\n"
"    background-color: #272c36;\n"
"}\n"
"\n"
"QComboBox::drop-down:hover{\n"
"    background-color:black;\n"
"}\n"
"\n"
"QComboBox::down-arrow{\n"
"    image:url(:/icon_w/assets/svg_white/circle-down.svg);\n"
"    width: 18px;\n"
"    height:18px;\n"
"}\n"
"\n"
"\n"
"/* TabWidget */\n"
"QTabWidget::pane { /* The tab widget frame */\n"
"    border-top: 2px solid #1b1e23;\n"
"    background-color:#1b1e23;\n"
"    border-radius: 8px;\n"
"    border-top-left-radius:0px;\n"
"}\n"
"\n"
"QTabWidget::tab-bar {\n"
"    left: 0px; /* move to the right by 5px */\n"
"}\n"
"\n"
"/* Style the tab using the tab sub-control. Note that\n"
"    it reads QTabBar _not_ QTabWidget */\n"
"QTabBar::tab {\n"
"    /* background: #1b1e23;\n"
"    border-bottom-color: #1b1e23;  */\n"
"    background:#2c313c;\n"
"    border-top-left-radius: 8px;\n"
"    border-top-right-radius: 8px;\n"
"    min-width: 8ex;\n"
"    padding: 8px;\n"
"}\n"
"\n"
"QTabBar::tab:selected, QTabBar::tab:hover {\n"
"    backgroun"
                        "d: #1b1e23;\n"
"    /* color:black; */\n"
"}\n"
"\n"
"QTabBar::tab:!selected {\n"
"    margin-top: 2px; /* make non-selected tabs look smaller */\n"
"}\n"
"\n"
"\n"
"QScrollArea{\n"
"    background-color: transparent;\n"
"}\n"
"\n"
"\n"
"QScrollArea #scrollAreaWidgetContents *{\n"
"    margin-right:5px;\n"
"}\n"
"\n"
"\n"
"\n"
"#Notification QToolButton{\n"
"    padding-left:20px;\n"
"    padding-right:20px;\n"
"    color:black;\n"
"}\n"
"\n"
"QSplitter::handle{\n"
"    background-color: #2c313c;\n"
"    margin-top:5px;\n"
"    margin-bottom: 5px;\n"
"}\n"
"\n"
"\n"
"QTableWidget, QTableView{\n"
"	background-color:#343b48;\n"
"	/* padding:5px; */\n"
"gridline-color:#2c313c;\n"
"}\n"
"\n"
"QTableWidget::item,\n"
"QTableView::item{\n"
"border-color:none;\n"
"padding-left:5px;\n"
"padding-right:5px;\n"
"gridline-color:rgb(44, 49, 60);\n"
"border-bottom: 1px solid #3c4454;\n"
"}\n"
"\n"
"QTableWidget::item:selected,\n"
"QTableView::item:selected{\n"
"	background-color: #568af2;\n"
"}\n"
"\n"
"QHeaderView::section{"
                        "\n"
"	background-color: rgb(33, 37, 43);\n"
"	max-width: 30px;\n"
"	border: 1px solid rgb(44, 49, 58);\n"
"	border-style: none;\n"
"    border-bottom: 1px solid rgb(44, 49, 60);\n"
"    border-right: 1px solid rgb(44, 49, 60);\n"
"}\n"
"\n"
"QTableWidget::horizontalHeader,\n"
"QTableView::horizontalHeader {\n"
"	background-color: rgb(33, 37, 43);\n"
"}\n"
"\n"
"QTableWidget QTableCornerButton::section,\n"
"QTableView QTableCornerButton::section\n"
" {\n"
"    border: none;\n"
"	background-color: rgb(33, 37, 43);\n"
"	padding: 3px;\n"
"    border-top-left-radius: 8px;\n"
"}\n"
"\n"
"QHeaderView::section:horizontal\n"
"{\n"
"    border: none;\n"
"	background-color: rgb(33, 37, 43);\n"
"	padding: 3px;\n"
"}\n"
"\n"
"QHeaderView::section:vertical\n"
"{\n"
"    border: none;\n"
"	background-color: rgb(33, 37, 43);\n"
"	padding-left: 5px;\n"
"    padding-right: 5px;\n"
"    border-bottom: 1px solid #3c4454;\n"
"}\n"
"\n"
"\n"
"\n"
"QHeaderView {\n"
"    background-color: #21252b;\n"
"}\n"
"\n"
"QHeaderView::section:"
                        "horizontal:first\n"
"{\n"
"\n"
"	background-color: rgb(33, 37, 43);\n"
"	padding: 3px;\n"
"border-top-left-radius: 8px;\n"
"}\n"
"\n"
"QHeaderView::section:horizontal:last\n"
"{\n"
"\n"
"	background-color: rgb(33, 37, 43);\n"
"	padding: 3px;\n"
"border-top-right-radius: 8px;\n"
"}\n"
"\n"
"QTableWidget QLineEdit,\n"
"QTableView QLineEdit{\n"
"	padding:2px;\n"
"background-color:#568af2;\n"
"color:black;\n"
"}\n"
"\n"
"\n"
"/* profiler */\n"
"\n"
"Monitor QFrame {\n"
"background-color: #1b1e23;\n"
"}\n"
"\n"
"\n"
"Logcat #container {\n"
"    background-color: #343b48;\n"
"}\n"
"")
        self.action_copy = QAction(Logcat)
        self.action_copy.setObjectName(u"action_copy")
        self.verticalLayout_3 = QVBoxLayout(Logcat)
        self.verticalLayout_3.setObjectName(u"verticalLayout_3")
        self.container = QFrame(Logcat)
        self.container.setObjectName(u"container")
        self.verticalLayout_2 = QVBoxLayout(self.container)
        self.verticalLayout_2.setObjectName(u"verticalLayout_2")
        self.horizontalLayout = QHBoxLayout()
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.label = QLabel(self.container)
        self.label.setObjectName(u"label")

        self.horizontalLayout.addWidget(self.label)

        self.le_search = QLineEdit(self.container)
        self.le_search.setObjectName(u"le_search")
        self.le_search.setMaximumSize(QSize(16777215, 36))

        self.horizontalLayout.addWidget(self.le_search)

        self.lb_tag = QLabel(self.container)
        self.lb_tag.setObjectName(u"lb_tag")

        self.horizontalLayout.addWidget(self.lb_tag)

        self.le_tag = QLineEdit(self.container)
        self.le_tag.setObjectName(u"le_tag")
        self.le_tag.setMaximumSize(QSize(16777215, 36))

        self.horizontalLayout.addWidget(self.le_tag)

        self.lb_priority = QLabel(self.container)
        self.lb_priority.setObjectName(u"lb_priority")

        self.horizontalLayout.addWidget(self.lb_priority)

        self.cbx_priority = QComboBox(self.container)
        self.cbx_priority.addItem("")
        self.cbx_priority.addItem("")
        self.cbx_priority.addItem("")
        self.cbx_priority.addItem("")
        self.cbx_priority.addItem("")
        self.cbx_priority.addItem("")
        self.cbx_priority.addItem("")
        self.cbx_priority.setObjectName(u"cbx_priority")

        self.horizontalLayout.addWidget(self.cbx_priority)

        self.btn_start = QPushButton(self.container)
        self.btn_start.setObjectName(u"btn_start")
        self.btn_start.setMaximumSize(QSize(36, 36))
        icon = QIcon()
        icon.addFile(u":/icon_w/assets/svg_white/play2.svg", QSize(), QIcon.Normal, QIcon.Off)
        icon.addFile(u":/icon/assets/svg/play2.svg", QSize(), QIcon.Normal, QIcon.On)
        self.btn_start.setIcon(icon)
        self.btn_start.setCheckable(True)

        self.horizontalLayout.addWidget(self.btn_start)

        self.btn_save = QPushButton(self.container)
        self.btn_save.setObjectName(u"btn_save")
        self.btn_save.setMaximumSize(QSize(36, 36))
        icon1 = QIcon()
        icon1.addFile(u":/icon_w/assets/svg_white/save.svg", QSize(), QIcon.Normal, QIcon.Off)
        icon1.addFile(u":/icon/assets/svg/save.svg", QSize(), QIcon.Normal, QIcon.On)
        self.btn_save.setIcon(icon1)

        self.horizontalLayout.addWidget(self.btn_save)

        self.btn_clear = QPushButton(self.container)
        self.btn_clear.setObjectName(u"btn_clear")
        self.btn_clear.setMaximumSize(QSize(36, 36))
        icon2 = QIcon()
        icon2.addFile(u":/icon_w/assets/svg_white/bin.svg", QSize(), QIcon.Normal, QIcon.On)
        icon2.addFile(u":/icon/assets/svg/bin.svg", QSize(), QIcon.Disabled, QIcon.Off)
        self.btn_clear.setIcon(icon2)

        self.horizontalLayout.addWidget(self.btn_clear)


        self.verticalLayout_2.addLayout(self.horizontalLayout)

        self.tbv_logs = QTableView(self.container)
        self.tbv_logs.setObjectName(u"tbv_logs")
        self.tbv_logs.setContextMenuPolicy(Qt.ActionsContextMenu)
        self.tbv_logs.setDefaultDropAction(Qt.IgnoreAction)
        self.tbv_logs.setSelectionMode(QAbstractItemView.ExtendedSelection)
        self.tbv_logs.setSelectionBehavior(QAbstractItemView.SelectRows)
        self.tbv_logs.setTextElideMode(Qt.ElideRight)
        self.tbv_logs.setCornerButtonEnabled(False)
        self.tbv_logs.horizontalHeader().setDefaultSectionSize(100)
        self.tbv_logs.horizontalHeader().setProperty("showSortIndicator", True)
        self.tbv_logs.horizontalHeader().setStretchLastSection(True)
        self.tbv_logs.verticalHeader().setVisible(False)

        self.verticalLayout_2.addWidget(self.tbv_logs)


        self.verticalLayout_3.addWidget(self.container)


        self.retranslateUi(Logcat)

        QMetaObject.connectSlotsByName(Logcat)
    # setupUi

    def retranslateUi(self, Logcat):
        Logcat.setWindowTitle(QCoreApplication.translate("Logcat", u"Form", None))
        self.action_copy.setText(QCoreApplication.translate("Logcat", u"\u590d\u5236", None))
        self.label.setText(QCoreApplication.translate("Logcat", u"\u641c\u7d22\u5185\u5bb9\uff1a", None))
        self.lb_tag.setText(QCoreApplication.translate("Logcat", u"\u6807\u7b7e\uff1a", None))
        self.lb_priority.setText(QCoreApplication.translate("Logcat", u"\u4f18\u5148\u7ea7\uff1a", None))
        self.cbx_priority.setItemText(0, "")
        self.cbx_priority.setItemText(1, QCoreApplication.translate("Logcat", u"V", None))
        self.cbx_priority.setItemText(2, QCoreApplication.translate("Logcat", u"D", None))
        self.cbx_priority.setItemText(3, QCoreApplication.translate("Logcat", u"I", None))
        self.cbx_priority.setItemText(4, QCoreApplication.translate("Logcat", u"W", None))
        self.cbx_priority.setItemText(5, QCoreApplication.translate("Logcat", u"E", None))
        self.cbx_priority.setItemText(6, QCoreApplication.translate("Logcat", u"F", None))

        self.btn_start.setText("")
        self.btn_save.setText("")
        self.btn_clear.setText("")
    # retranslateUi




#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    :   __init__.py
@Time    :   2022/04/27 23:57:16
@Author  :   Calros Teng 
@Version :   1.0
@Contact :   303359166@qq.com
@License :   (C)Copyright 2017-2018, Xin Yuan Studio
@Desc    :   
windows平台可以用win32api的方式来移动窗口
其他系统就用Qt的解决方法了

PS:
[1] 其实直接用通用Tilebar就好了……目前来讲就只有移动方案分家了
[2] 不过我保留两种方案，供其他人学习
"""

# here put the import lib


import sys
import logging

log = logging.getLogger(__name__)

if sys.platform == "win32":
    log.debug("使用 win titlebar")
    from .win_title_bar import WinTitleBar as TitleBar
else:
    log.debug("使用 通用 titlebar")
    from .comm_title_bar import CommTitleBar as TitleBar




"""
## 纯QEvent方案（失败）

app实现设备热拔插事件，然后自上而下广播给page。

Qt中，事件是由下而上传递，app.sendEvent 不会往下传递给所有子widget。
反过来子widget.sendEvent只要没被accept就会一直往上传递

因此无法靠自定义QEvent的方式广播 usb设备 热拔插事件给所有pages

## EventFilter+Signal方案 

自定义EventFilter，创建一个单例EventFilter然后安装到app上。
因为EventFilter是个单例，所以所有page都可以引入去connect他的signal。


"""

import sys

if sys.platform == 'win32':
    from .win import WinHotPlugNativeEventFilter as HotPlugNativeEventFilter

elif sys.platform == 'linux':
    from .linux import LinuxHotPlugNatvieEventFilter as HotPlugNativeEventFilter
elif sys.platform == 'darwin':
    from .base import BaseHotPlugNativeEventFilter as HotPlugNativeEventFilter

HotPlugWatcher = HotPlugNativeEventFilter()


#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    :   fps_monitor.py
@Time    :   2022/05/13 16:58:00
@Author  :   Calros Teng 
@Version :   1.0
@Contact :   303359166@qq.com
@License :   (C)Copyright 2017-2018, Xin Yuan Studio
@Desc    :   emm...
fps采样
"""

# here put the import lib
from ppadb.device import Device
from .base.chart import MonitorChart
from PySide6.QtCharts import QScatterSeries,QLineSeries
from perfcat.modules.profiler.fps import FpsSampler


class FpsMonitor(MonitorChart):
    def __init__(self, parent):
        super().__init__(
            parent,
            y_axis_name="FPS",
        )
        self.setObjectName("FPS")

        series = QLineSeries(self)
        self.create_series("FPS", series, lambda v:f"{v}")

        series = QScatterSeries(self)
        self.create_series("Jank-卡顿", series, lambda v:f"{v}次")

        series = QScatterSeries(self)
        self.create_series("BigJank-大卡顿", series, lambda v:f"{v}次")

        self.fps_sampler = None

        self._sample_data = {}

    def sample(self, sec: int, device: Device, package_name: str):
        if self.fps_sampler is None:
            self.fps_sampler = FpsSampler(device, package_name)
        data = self.fps_sampler.data
        self.add_point("FPS", sec, data["fps"])
        if data["jank"] > 0:
            self.add_point("Jank-卡顿", sec, data["jank"])

        if data["big_jank"] > 0:
            self.add_point("BigJank-大卡顿", sec, data["big_jank"])

        self._sample_data[sec] = data

    def reset_series_data(self):
        self.fps_sampler = None
        self._sample_data = {}
        return super().reset_series_data()


    def to_dict(self, all: bool = True) -> dict:

        if all:
            return self._sample_data
        else:
            start = self.record_range[0]
            end = self.record_range[1]

            data = {}
            for k,v in self._sample_data.items():
                if start <= k <= end:
                    data[k] = v
            return data

    def from_dict(self, data: dict):
        for sec, data_table in data.items():
            fps = data_table["fps"]
            jank_value = data_table['jank']
            big_jank_value = data_table['big_jank']

            if fps:
                self.add_point("FPS", int(sec), fps)

            if jank_value:
                self.add_point("Jank-卡顿", int(sec), jank_value)

            if big_jank_value:
                self.add_point("BigJank-大卡顿", int(sec), big_jank_value)

            self.flush()



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    :   left_menu.py
@Time    :   2022/04/27 14:39:00
@Author  :   Calros Teng 
@Version :   1.0
@Contact :   303359166@qq.com
@License :   (C)Copyright 2017-2018, Xin Yuan Studio
@Desc    :   侧边导航栏组件
"""

# here put the import lib


import textwrap
import PySide6
import logging
from PySide6.QtWidgets import (
    QWidget,
    QGraphicsDropShadowEffect,
    QButtonGroup,
    QVBoxLayout,
    QPushButton,
)
from PySide6.QtCore import QTimer
from perfcat.settings import settings
from .ui_left_menu import Ui_LeftMenu
from .. import util

log = logging.getLogger(__name__)


class LeftMenu(QWidget, Ui_LeftMenu):

    # 展开最大宽度，收起最小宽度，目前只能写死了
    MAX_WIDTH = 240
    MIN_WIDTH = 50

    def __init__(self, parent):
        super().__init__(parent)
        self.setupUi(self)
        self.setStyleSheet("")  # 清空qt designer里写死的样式

        # 菜单展开和收起功能
        self.btn_toggle.setChecked(True)
        self.btn_toggle.toggled.connect(self.expand)

        # 清空掉nav_menu设计时按钮
        util.clear_layout(self.nav_menu)
        self.btn_home.deleteLater()
        self.nav_menu_group = QButtonGroup(self)

        # 把关于和设置按钮放到按钮组里
        self.bottom_btn_group = QButtonGroup(self)
        self.bottom_btn_group.addButton(self.btn_setting, 0)
        self.bottom_btn_group.addButton(self.btn_about, 1)

    def showEvent(self, event: PySide6.QtGui.QShowEvent) -> None:
        # 读取上一次展开关闭状态
        expanded = settings.value("left_menu/expanded", True, bool)
        self.expand(expanded)
        log.debug(f"读取上一次展开关闭状态 {expanded}")
        return super().showEvent(event)

    def add_nav_menu(self, icon, text, binding_page_name):
        indented_text = textwrap.indent(text, " " * 4)  # 缩进4格用来适配按钮样式
        btn_menu = QPushButton(icon, indented_text, self)
        btn_menu.setCheckable(True)
        btn_menu.setObjectName(binding_page_name)
        btn_menu.setToolTip(indented_text)

        self.nav_menu.layout().addWidget(btn_menu)
        self.nav_menu_group.addButton(btn_menu)
        if self.nav_menu.layout().count() == 1:
            btn_menu.setChecked(True)

    def bottom_btn_group_reset(self):
        self.bottom_btn_group.setExclusive(False)
        for btn in self.bottom_btn_group.buttons():
            btn.setChecked(False)
        self.bottom_btn_group.setExclusive(True)

    def expand(self, checked):
        log.debug(f"展开关闭导航菜单 {checked}")
        settings.setValue("left_menu/expanded", checked)

        self.btn_toggle.blockSignals(True)
        self.btn_toggle.setChecked(checked)
        self.btn_toggle.blockSignals(False)

        util.set_h_expand_anim(
            self.parentWidget(), checked, self.MAX_WIDTH, self.MIN_WIDTH
        )
